@@ -158,11 +158,11 @@ bitflags! {
 }}
 
 impl<T: PolarsDataType> ChunkedArray<T> {
-    pub(crate) fn is_sorted_flag(&self) -> bool {
+    pub(crate) fn is_sorted_ascending_flag(&self) -> bool {
         self.bit_settings.contains(Settings::SORTED_ASC)
     }
 
-    pub(crate) fn is_sorted_reverse_flag(&self) -> bool {
+    pub(crate) fn is_sorted_descending_flag(&self) -> bool {
         self.bit_settings.contains(Settings::SORTED_DSC)
     }
 
@@ -171,9 +171,9 @@ impl<T: PolarsDataType> ChunkedArray<T> {
     }
 
     pub fn is_sorted_flag2(&self) -> IsSorted {
-        if self.is_sorted_flag() {
+        if self.is_sorted_ascending_flag() {
             IsSorted::Ascending
-        } else if self.is_sorted_reverse_flag() {
+        } else if self.is_sorted_descending_flag() {
             IsSorted::Descending
         } else {
             IsSorted::Not
@@ -188,15 +188,15 @@ impl<T: PolarsDataType> ChunkedArray<T> {
                     .remove(Settings::SORTED_ASC | Settings::SORTED_DSC);
             }
             IsSorted::Ascending => {
-                // // unset reverse sorted
+                // // unset descending sorted
                 self.bit_settings.remove(Settings::SORTED_DSC);
-                // set sorted
+                // set ascending sorted
                 self.bit_settings.insert(Settings::SORTED_ASC)
             }
             IsSorted::Descending => {
-                // unset sorted
+                // unset ascending sorted
                 self.bit_settings.remove(Settings::SORTED_ASC);
-                // set reverse sorted
+                // set descending sorted
                 self.bit_settings.insert(Settings::SORTED_DSC)
             }
         }
@@ -648,7 +648,7 @@ pub(crate) mod test {
         let a = a.sort(false);
         let b = a.into_iter().collect::<Vec<_>>();
         assert_eq!(b, [Some("a"), Some("b"), Some("c")]);
-        assert_eq!(a.is_sorted_flag(), true);
+        assert_eq!(a.is_sorted_ascending_flag(), true);
     }
 
     #[test]
