@@ -6,7 +6,7 @@ use polars_utils::{flatten, HashSingle};
 
 use super::*;
 use crate::config::verbose;
-use crate::utils::{_split_offsets, copy_from_slice_unchecked};
+use crate::utils::_split_offsets;
 
 /// Used to create the tuples for a groupby operation.
 pub trait IntoGroupsProxy {
@@ -104,7 +104,8 @@ where
 
         let n_threads = POOL.current_num_threads();
         let groups = if multithreaded && n_threads > 1 {
-            let parts = create_clean_partitions(values, n_threads, self.is_sorted_reverse_flag());
+            let parts =
+                create_clean_partitions(values, n_threads, self.is_sorted_descending_flag());
             let n_parts = parts.len();
 
             let first_ptr = &values[0] as *const T::Native as usize;
@@ -152,7 +153,9 @@ where
 {
     fn group_tuples(&self, multithreaded: bool, sorted: bool) -> PolarsResult<GroupsProxy> {
         // sorted path
-        if self.is_sorted_flag() || self.is_sorted_reverse_flag() && self.chunks().len() == 1 {
+        if self.is_sorted_ascending_flag()
+            || self.is_sorted_descending_flag() && self.chunks().len() == 1
+        {
             // don't have to pass `sorted` arg, GroupSlice is always sorted.
             return Ok(GroupsProxy::Slice {
                 groups: self.create_groups_from_sorted(multithreaded),
@@ -423,202 +426,3 @@ where
         Ok(groupby(self.into_iter(), sorted))
     }
 }
-
-/// Used to tightly two 32 bit values and null information
-/// Only the bit values matter, not the meaning of the bits
-#[inline]
-pub(super) fn pack_u32_tuples(opt_l: Option<u32>, opt_r: Option<u32>) -> [u8; 9] {
-    // 4 bytes for first value
-    // 4 bytes for second value
-    // last bytes' bits are used to indicate missing values
-    let mut val = [0u8; 9];
-    let s = &mut val;
-    match (opt_l, opt_r) {
-        (Some(l), Some(r)) => {
-            // write to first 4 places
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..4]) }
-            // write to second chunk of 4 places
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[4..8]) }
-            // leave last byte as is
-        }
-        (Some(l), None) => {
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..4]) }
-            // set right null bit
-            s[8] = 1;
-        }
-        (None, Some(r)) => {
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[4..8]) }
-            // set left null bit
-            s[8] = 1 << 1;
-        }
-        (None, None) => {
-            // set two null bits
-            s[8] = 3;
-        }
-    }
-    val
-}
-
-/// Used to tightly two 64 bit values and null information
-/// Only the bit values matter, not the meaning of the bits
-#[inline]
-pub(super) fn pack_u64_tuples(opt_l: Option<u64>, opt_r: Option<u64>) -> [u8; 17] {
-    // 8 bytes for first value
-    // 8 bytes for second value
-    // last bytes' bits are used to indicate missing values
-    let mut val = [0u8; 17];
-    let s = &mut val;
-    match (opt_l, opt_r) {
-        (Some(l), Some(r)) => {
-            // write to first 4 places
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..8]) }
-            // write to second chunk of 4 places
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[8..16]) }
-            // leave last byte as is
-        }
-        (Some(l), None) => {
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..8]) }
-            // set right null bit
-            s[16] = 1;
-        }
-        (None, Some(r)) => {
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[8..16]) }
-            // set left null bit
-            s[16] = 1 << 1;
-        }
-        (None, None) => {
-            // set two null bits
-            s[16] = 3;
-        }
-    }
-    val
-}
-
-/// Used to tightly one 32 bit and a 64 bit valued type and null information
-/// Only the bit values matter, not the meaning of the bits
-#[inline]
-pub(super) fn pack_u32_u64_tuples(opt_l: Option<u32>, opt_r: Option<u64>) -> [u8; 13] {
-    // 8 bytes for first value
-    // 8 bytes for second value
-    // last bytes' bits are used to indicate missing values
-    let mut val = [0u8; 13];
-    let s = &mut val;
-    match (opt_l, opt_r) {
-        (Some(l), Some(r)) => {
-            // write to first 4 places
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..4]) }
-            // write to second chunk of 4 places
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[4..12]) }
-            // leave last byte as is
-        }
-        (Some(l), None) => {
-            unsafe { copy_from_slice_unchecked(&l.to_ne_bytes(), &mut s[..4]) }
-            // set right null bit
-            s[12] = 1;
-        }
-        (None, Some(r)) => {
-            unsafe { copy_from_slice_unchecked(&r.to_ne_bytes(), &mut s[4..12]) }
-            // set left null bit
-            s[12] = 1 << 1;
-        }
-        (None, None) => {
-            // set two null bits
-            s[12] = 3;
-        }
-    }
-    val
-}
-
-/// We will pack the utf8 columns into single column. Nulls are encoded in the start of the string
-/// by either:
-/// 11 => both valid
-/// 00 => both null
-/// 10 => first valid
-/// 01 => second valid
-pub(super) fn pack_utf8_columns(
-    lhs: &Utf8Chunked,
-    rhs: &Utf8Chunked,
-    n_partitions: usize,
-    sorted: bool,
-) -> GroupsProxy {
-    let splits = _split_offsets(lhs.len(), n_partitions);
-    let hb = RandomState::default();
-    let null_h = get_null_hash_value(hb.clone());
-
-    let (hashes, _backing_bytes): (Vec<_>, Vec<_>) = splits
-        .into_par_iter()
-        .map(|(offset, len)| {
-            let lhs = lhs.slice(offset as i64, len);
-            let rhs = rhs.slice(offset as i64, len);
-
-            // the additional:
-            // 2 is needed for the validity
-            // 1 for the '_' delimiter
-            let size = lhs.get_values_size() + rhs.get_values_size() + lhs.len() * 3 + 1;
-
-            let mut values = Vec::with_capacity(size);
-            let ptr = values.as_ptr() as usize;
-            let mut str_hashes = Vec::with_capacity(lhs.len());
-
-            lhs.into_iter().zip(rhs.into_iter()).for_each(|(lhs, rhs)| {
-                match (lhs, rhs) {
-                    (Some(lhs), Some(rhs)) => {
-                        let start = values.len();
-                        values.extend_from_slice("11".as_bytes());
-                        values.extend_from_slice(lhs.as_bytes());
-                        values.push(b'_');
-                        values.extend_from_slice(rhs.as_bytes());
-                        // reallocated lifetime is invalid
-                        debug_assert_eq!(ptr, values.as_ptr() as usize);
-                        let end = values.len();
-                        // Safety:
-                        // - we know the bytes are valid utf8
-                        // - we are in bounds
-                        // - the lifetime as long as `values` not is dropped
-                        //   so `str_val` may never leave this function
-                        let str_val: &'static str = unsafe {
-                            std::mem::transmute(std::str::from_utf8_unchecked(
-                                values.get_unchecked(start..end),
-                            ))
-                        };
-                        let hash = hb.hash_single(str_val);
-                        str_hashes.push(BytesHash::new(Some(str_val.as_bytes()), hash))
-                    }
-                    (None, Some(rhs)) => {
-                        let start = values.len();
-                        values.extend_from_slice("01".as_bytes());
-                        values.push(b'_');
-                        values.extend_from_slice(rhs.as_bytes());
-                        debug_assert_eq!(ptr, values.as_ptr() as usize);
-                        let end = values.len();
-                        let str_val: &'static str = unsafe {
-                            std::mem::transmute(std::str::from_utf8_unchecked(
-                                values.get_unchecked(start..end),
-                            ))
-                        };
-                        let hash = hb.hash_single(str_val);
-                        str_hashes.push(BytesHash::new(Some(str_val.as_bytes()), hash))
-                    }
-                    (Some(lhs), None) => {
-                        let start = values.len();
-                        values.extend_from_slice("10".as_bytes());
-                        values.extend_from_slice(lhs.as_bytes());
-                        values.push(b'_');
-                        debug_assert_eq!(ptr, values.as_ptr() as usize);
-                        let end = values.len();
-                        let str_val: &'static str = unsafe {
-                            std::mem::transmute(std::str::from_utf8_unchecked(
-                                values.get_unchecked(start..end),
-                            ))
-                        };
-                        let hash = hb.hash_single(str_val);
-                        str_hashes.push(BytesHash::new(Some(str_val.as_bytes()), hash))
-                    }
-                    (None, None) => str_hashes.push(BytesHash::new(None, null_h)),
-                }
-            });
-            (str_hashes, values)
-        })
-        .unzip();
-    groupby_threaded_num(hashes, 0, n_partitions as u64, sorted)
-}
