@@ -173,16 +173,16 @@ macro_rules! impl_dyn_series {
                 self.0.group_tuples(multithreaded, sorted)
             }
             #[cfg(feature = "sort_multiple")]
-            fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-                self.0.deref().arg_sort_multiple(by, reverse)
+            fn arg_sort_multiple(&self, by: &[Series], descending: &[bool]) -> PolarsResult<IdxCa> {
+                self.0.deref().arg_sort_multiple(by, descending)
             }
         }
 
         impl SeriesTrait for SeriesWrap<$ca> {
             fn is_sorted_flag(&self) -> IsSorted {
-                if self.0.is_sorted_flag() {
+                if self.0.is_sorted_ascending_flag() {
                     IsSorted::Ascending
-                } else if self.0.is_sorted_reverse_flag() {
+                } else if self.0.is_sorted_descending_flag() {
                     IsSorted::Descending
                 } else {
                     IsSorted::Not
@@ -292,7 +292,8 @@ macro_rules! impl_dyn_series {
             unsafe fn take_unchecked(&self, idx: &IdxCa) -> PolarsResult<Series> {
                 let mut out = ChunkTake::take_unchecked(self.0.deref(), idx.into());
 
-                if self.0.is_sorted_flag() && (idx.is_sorted_flag() || idx.is_sorted_reverse_flag())
+                if self.0.is_sorted_ascending_flag()
+                    && (idx.is_sorted_ascending_flag() || idx.is_sorted_descending_flag())
                 {
                     out.set_sorted_flag(idx.is_sorted_flag2())
                 }
