@@ -139,16 +139,16 @@ macro_rules! impl_dyn_series {
             }
 
             #[cfg(feature = "sort_multiple")]
-            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-                self.0.argsort_multiple(by, reverse)
+            fn arg_sort_multiple(&self, by: &[Series], descending: &[bool]) -> PolarsResult<IdxCa> {
+                self.0.arg_sort_multiple(by, descending)
             }
         }
 
         impl SeriesTrait for SeriesWrap<$ca> {
             fn is_sorted_flag(&self) -> IsSorted {
-                if self.0.is_sorted_flag() {
+                if self.0.is_sorted_ascending_flag() {
                     IsSorted::Ascending
-                } else if self.0.is_sorted_reverse_flag() {
+                } else if self.0.is_sorted_descending_flag() {
                     IsSorted::Descending
                 } else {
                     IsSorted::Not
@@ -260,7 +260,8 @@ macro_rules! impl_dyn_series {
 
                 let mut out = ChunkTake::take_unchecked(&self.0, (&*idx).into());
 
-                if self.0.is_sorted_flag() && (idx.is_sorted_flag() || idx.is_sorted_reverse_flag())
+                if self.0.is_sorted_ascending_flag()
+                    && (idx.is_sorted_ascending_flag() || idx.is_sorted_descending_flag())
                 {
                     out.set_sorted_flag(idx.is_sorted_flag2())
                 }
@@ -307,8 +308,8 @@ macro_rules! impl_dyn_series {
                 ChunkSort::sort_with(&self.0, options).into_series()
             }
 
-            fn argsort(&self, options: SortOptions) -> IdxCa {
-                ChunkSort::argsort(&self.0, options)
+            fn arg_sort(&self, options: SortOptions) -> IdxCa {
+                ChunkSort::arg_sort(&self.0, options)
             }
 
             fn null_count(&self) -> usize {
@@ -339,14 +340,6 @@ macro_rules! impl_dyn_series {
                 self.0.is_not_null()
             }
 
-            fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-                ChunkUnique::is_unique(&self.0)
-            }
-
-            fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-                ChunkUnique::is_duplicated(&self.0)
-            }
-
             fn reverse(&self) -> Series {
                 ChunkReverse::reverse(&self.0).into_series()
             }
