@@ -214,9 +214,9 @@ impl Series {
         Ok(self)
     }
 
-    pub fn sort(&self, reverse: bool) -> Self {
+    pub fn sort(&self, descending: bool) -> Self {
         self.sort_with(SortOptions {
-            descending: reverse,
+            descending,
             ..Default::default()
         })
     }
@@ -407,10 +407,10 @@ impl Series {
     pub fn to_physical_repr(&self) -> Cow<Series> {
         use DataType::*;
         match self.dtype() {
-            Date => Cow::Owned(self.cast(&DataType::Int32).unwrap()),
-            Datetime(_, _) | Duration(_) | Time => Cow::Owned(self.cast(&DataType::Int64).unwrap()),
+            Date => Cow::Owned(self.cast(&Int32).unwrap()),
+            Datetime(_, _) | Duration(_) | Time => Cow::Owned(self.cast(&Int64).unwrap()),
             #[cfg(feature = "dtype-categorical")]
-            Categorical(_) => Cow::Owned(self.cast(&DataType::UInt32).unwrap()),
+            Categorical(_) => Cow::Owned(self.cast(&UInt32).unwrap()),
             _ => Cow::Borrowed(self),
         }
     }
@@ -551,7 +551,9 @@ impl Series {
     /// first cast to `Int64` to prevent overflow issues.
     pub fn sum_as_series(&self) -> Series {
         use DataType::*;
-        if self.is_empty() && self.dtype().is_numeric() {
+        if self.is_empty()
+            && (self.dtype().is_numeric() || matches!(self.dtype(), DataType::Boolean))
+        {
             return Series::new("", [0])
                 .cast(self.dtype())
                 .unwrap()
