@@ -94,7 +94,7 @@ pub(crate) mod private {
         }
 
         fn _set_sorted_flag(&mut self, _is_sorted: IsSorted) {
-            invalid_operation_panic!(self)
+            // ignore
         }
 
         unsafe fn equal_element(
@@ -178,7 +178,7 @@ pub(crate) mod private {
             invalid_operation_panic!(self)
         }
         #[cfg(feature = "sort_multiple")]
-        fn arg_sort_multiple(&self, _by: &[Series], _reverse: &[bool]) -> PolarsResult<IdxCa> {
+        fn arg_sort_multiple(&self, _by: &[Series], _descending: &[bool]) -> PolarsResult<IdxCa> {
             Err(PolarsError::InvalidOperation(
                 "arg_sort_multiple is not implemented for this Series".into(),
             ))
