@@ -8,6 +8,6 @@ mod ipc_stream;
 mod mmap;
 
 #[cfg(feature = "ipc")]
-pub use ipc_file::{IpcCompression, IpcReader, IpcWriter, IpcWriterOption};
+pub use ipc_file::{BatchedWriter, IpcCompression, IpcReader, IpcWriter, IpcWriterOption};
 #[cfg(feature = "ipc_streaming")]
 pub use ipc_stream::*;
