@@ -158,9 +158,8 @@ impl<'a> CoreJsonReader<'a> {
                 let bytes: &[u8] = &reader_bytes;
                 let mut cursor = Cursor::new(bytes);
 
-                let data_type = arrow_ndjson::read::infer(&mut cursor, infer_schema_len).unwrap();
-                let schema: polars_core::prelude::Schema =
-                    StructArray::get_fields(&data_type).iter().into();
+                let data_type = arrow_ndjson::read::infer(&mut cursor, infer_schema_len)?;
+                let schema: Schema = StructArray::get_fields(&data_type).iter().into();
 
                 Cow::Owned(schema)
             }
@@ -196,7 +195,7 @@ impl<'a> CoreJsonReader<'a> {
             }
         }
 
-        if total_rows == 128 {
+        if total_rows <= 128 {
             n_threads = 1;
         }
 
@@ -208,7 +207,6 @@ impl<'a> CoreJsonReader<'a> {
         } else {
             std::cmp::min(rows_per_thread, max_proxy)
         };
-
         let file_chunks = get_file_chunks_json(bytes, n_threads);
         let dfs = POOL.install(|| {
             file_chunks
@@ -216,12 +214,11 @@ impl<'a> CoreJsonReader<'a> {
                 .map(|(start_pos, stop_at_nbytes)| {
                     let mut buffers = init_buffers(&self.schema, capacity)?;
                     let _ = parse_lines(&bytes[start_pos..stop_at_nbytes], &mut buffers);
-
                     DataFrame::new(
                         buffers
                             .into_values()
                             .map(|buf| buf.into_series())
-                            .collect::<PolarsResult<_>>()?,
+                            .collect::<_>(),
                     )
                 })
                 .collect::<PolarsResult<Vec<_>>>()
