@@ -44,7 +44,7 @@ impl CsvExec {
             .with_encoding(self.options.encoding)
             .with_rechunk(self.options.rechunk)
             .with_row_count(std::mem::take(&mut self.options.row_count))
-            .with_parse_dates(self.options.parse_dates)
+            .with_try_parse_dates(self.options.try_parse_dates)
             .finish()
     }
 }
