@@ -1,6 +1,6 @@
+use std::borrow::Cow;
 use std::sync::Arc;
 
-use polars_arrow::utils::CustomIterTools;
 use polars_core::frame::groupby::GroupsProxy;
 use polars_core::prelude::*;
 use polars_core::POOL;
@@ -24,6 +24,7 @@ pub struct ApplyExpr {
     pub auto_explode: bool,
     pub allow_rename: bool,
     pub pass_name_to_apply: bool,
+    pub input_schema: Option<SchemaRef>,
 }
 
 impl ApplyExpr {
@@ -41,6 +42,7 @@ impl ApplyExpr {
             auto_explode: false,
             allow_rename: false,
             pass_name_to_apply: false,
+            input_schema: None,
         }
     }
 
@@ -63,16 +65,117 @@ impl ApplyExpr {
         &self,
         mut ac: AggregationContext<'a>,
         ca: ListChunked,
-    ) -> AggregationContext<'a> {
+    ) -> PolarsResult<AggregationContext<'a>> {
         let all_unit_len = all_unit_length(&ca);
         if all_unit_len && self.auto_explode {
-            ac.with_series(ca.explode().unwrap().into_series(), true);
+            ac.with_series(ca.explode().unwrap().into_series(), true, Some(&self.expr))?;
             ac.update_groups = UpdateGroups::No;
         } else {
-            ac.with_series(ca.into_series(), true);
+            ac.with_series(ca.into_series(), true, Some(&self.expr))?;
             ac.with_update_groups(UpdateGroups::WithSeriesLen);
         }
-        ac
+        Ok(ac)
+    }
+
+    fn get_input_schema(&self, df: &DataFrame) -> Cow<Schema> {
+        match &self.input_schema {
+            Some(schema) => Cow::Borrowed(schema.as_ref()),
+            None => Cow::Owned(df.schema()),
+        }
+    }
+
+    fn eval_and_flatten(&self, inputs: &mut [Series]) -> PolarsResult<Series> {
+        self.function.call_udf(inputs).map(|opt_out| {
+            opt_out.unwrap_or_else(|| {
+                let field = self.to_field(self.input_schema.as_ref().unwrap()).unwrap();
+                Series::full_null(field.name(), 1, field.data_type())
+            })
+        })
+    }
+    fn apply_single_group_aware<'a>(
+        &self,
+        mut ac: AggregationContext<'a>,
+    ) -> PolarsResult<AggregationContext<'a>> {
+        let s = ac.series();
+
+        if matches!(ac.agg_state(), AggState::AggregatedFlat(_)) {
+            let msg = format!(
+                "Cannot aggregate {:?}. The column is already aggregated.",
+                self.expr
+            );
+            return Err(expression_err!(msg, self.expr, ComputeError));
+        }
+
+        let name = s.name().to_string();
+        let agg = ac.aggregated();
+        // collection of empty list leads to a null dtype
+        // see: #3687
+        if agg.len() == 0 {
+            // create input for the function to determine the output dtype
+            // see #3946
+            let agg = agg.list().unwrap();
+            let input_dtype = agg.inner_dtype();
+
+            let input = Series::full_null("", 0, &input_dtype);
+
+            let output = self.eval_and_flatten(&mut [input])?;
+            let ca = ListChunked::full(&name, &output, 0);
+            return self.finish_apply_groups(ac, ca);
+        }
+
+        let mut ca: ListChunked = POOL.install(|| {
+            agg.list()
+                .unwrap()
+                .par_iter()
+                .map(|opt_s| match opt_s {
+                    None => Ok(None),
+                    Some(mut s) => {
+                        if self.pass_name_to_apply {
+                            s.rename(&name);
+                        }
+                        let mut container = [s];
+                        self.function.call_udf(&mut container)
+                    }
+                })
+                .collect::<PolarsResult<_>>()
+        })?;
+
+        ca.rename(&name);
+        self.finish_apply_groups(ac, ca)
+    }
+    fn apply_single_flattened<'a>(
+        &self,
+        mut ac: AggregationContext<'a>,
+    ) -> PolarsResult<AggregationContext<'a>> {
+        // make sure the groups are updated because we are about to throw away
+        // the series' length information
+        let set_update_groups = match ac.update_groups {
+            UpdateGroups::WithSeriesLen => {
+                ac.groups();
+                true
+            }
+            UpdateGroups::WithSeriesLenOwned(_) => false,
+            UpdateGroups::No | UpdateGroups::WithGroupsLen => false,
+        };
+
+        if let UpdateGroups::WithSeriesLen = ac.update_groups {
+            ac.groups();
+        }
+
+        let input = ac.flat_naive().into_owned();
+        let input_len = input.len();
+        let s = self.eval_and_flatten(&mut [input])?;
+
+        check_map_output_len(input_len, s.len(), &self.expr)?;
+        ac.with_series(s, false, None)?;
+
+        if set_update_groups {
+            // The flat_naive orders by groups, so we must create new groups
+            // not by series length as we don't have an agg_list, but by original
+            // groups length
+            ac.update_groups = UpdateGroups::WithGroupsLen;
+        }
+        Ok(ac)
     }
 }
 
@@ -98,17 +201,18 @@ impl PhysicalExpr for ApplyExpr {
     }
 
     fn evaluate(&self, df: &DataFrame, state: &ExecutionState) -> PolarsResult<Series> {
-        let mut inputs = self
-            .inputs
-            .par_iter()
-            .map(|e| e.evaluate(df, state))
-            .collect::<PolarsResult<Vec<_>>>()?;
+        let mut inputs = POOL.install(|| {
+            self.inputs
+                .par_iter()
+                .map(|e| e.evaluate(df, state))
+                .collect::<PolarsResult<Vec<_>>>()
+        })?;
 
         if self.allow_rename {
-            return self.function.call_udf(&mut inputs);
+            return self.eval_and_flatten(&mut inputs);
         }
         let in_name = inputs[0].name().to_string();
-        let mut out = self.function.call_udf(&mut inputs)?;
+        let mut out = self.eval_and_flatten(&mut inputs)?;
         if in_name != out.name() {
             out.rename(&in_name);
         }
@@ -124,102 +228,36 @@ impl PhysicalExpr for ApplyExpr {
         if self.inputs.len() == 1 {
             let mut ac = self.inputs[0].evaluate_on_groups(df, groups, state)?;
 
-            match (state.overlapping_groups(), self.collect_groups) {
+            match (state.has_overlapping_groups(), self.collect_groups) {
                 (_, ApplyOptions::ApplyList) => {
-                    let s = self.function.call_udf(&mut [ac.aggregated()])?;
-                    ac.with_series(s, true);
+                    let s = self.eval_and_flatten(&mut [ac.aggregated()])?;
+                    ac.with_series(s, true, Some(&self.expr))?;
+                    Ok(ac)
+                }
+                // - series is aggregated flat/reduction: sum/min/mean etc.
+                // - apply options is apply_flat -> elementwise
+                // we can simply apply the function in a vectorized manner.
+                (_, ApplyOptions::ApplyFlat) if ac.is_aggregated_flat() => {
+                    let s = ac.aggregated();
+                    let s = self.eval_and_flatten(&mut [s])?;
+                    ac.with_series(s, true, Some(&self.expr))?;
                     Ok(ac)
                 }
                 // overlapping groups always take this branch as explode/flat_naive bloats data size
-                (_, ApplyOptions::ApplyGroups) | (true, _) => {
-                    let s = ac.series();
-
-                    if matches!(ac.agg_state(), AggState::AggregatedFlat(_)) {
-                        let msg = format!(
-                            "Cannot aggregate {:?}. The column is already aggregated.",
-                            self.expr
-                        );
-                        return Err(expression_err!(msg, self.expr, ComputeError));
-                    }
-
-                    let name = s.name().to_string();
-                    let agg = ac.aggregated();
-                    // collection of empty list leads to a null dtype
-                    // see: #3687
-                    if agg.len() == 0 {
-                        // create input for the function to determine the output dtype
-                        // see #3946
-                        let agg = agg.list().unwrap();
-                        let input_dtype = agg.inner_dtype();
-
-                        let input = Series::full_null("", 0, &input_dtype);
-
-                        let output = self.function.call_udf(&mut [input])?;
-                        let ca = ListChunked::full(&name, &output, 0);
-                        return Ok(self.finish_apply_groups(ac, ca));
-                    }
-
-                    let mut ca: ListChunked = agg
-                        .list()
-                        .unwrap()
-                        .par_iter()
-                        .map(|opt_s| {
-                            opt_s.and_then(|mut s| {
-                                if self.pass_name_to_apply {
-                                    s.rename(&name);
-                                }
-                                let mut container = [s];
-                                self.function.call_udf(&mut container).ok()
-                            })
-                        })
-                        .collect();
-
-                    ca.rename(&name);
-                    Ok(self.finish_apply_groups(ac, ca))
-                }
-                (_, ApplyOptions::ApplyFlat) => {
-                    // make sure the groups are updated because we are about to throw away
-                    // the series' length information
-                    let set_update_groups = match ac.update_groups {
-                        UpdateGroups::WithSeriesLen => {
-                            ac.groups();
-                            true
-                        }
-                        UpdateGroups::WithSeriesLenOwned(_) => false,
-                        UpdateGroups::No | UpdateGroups::WithGroupsLen => false,
-                    };
-
-                    if let UpdateGroups::WithSeriesLen = ac.update_groups {
-                        ac.groups();
-                    }
-
-                    let input = ac.flat_naive().into_owned();
-                    let input_len = input.len();
-                    let s = self.function.call_udf(&mut [input])?;
-
-                    check_map_output_len(input_len, s.len(), &self.expr)?;
-                    ac.with_series(s, false);
-
-                    if set_update_groups {
-                        // The flat_naive orders by groups, so we must create new groups
-                        // not by series length as we don't have an agg_list, but by original
-                        // groups length
-                        ac.update_groups = UpdateGroups::WithGroupsLen;
-                    }
-                    Ok(ac)
-                }
+                (_, ApplyOptions::ApplyGroups) | (true, _) => self.apply_single_group_aware(ac),
+                (_, ApplyOptions::ApplyFlat) => self.apply_single_flattened(ac),
             }
         } else {
             let mut acs = self.prepare_multiple_inputs(df, groups, state)?;
 
-            match (state.overlapping_groups(), self.collect_groups) {
+            match (state.has_overlapping_groups(), self.collect_groups) {
                 (_, ApplyOptions::ApplyList) => {
                     let mut s = acs.iter_mut().map(|ac| ac.aggregated()).collect::<Vec<_>>();
-                    let s = self.function.call_udf(&mut s)?;
+                    let s = self.eval_and_flatten(&mut s)?;
                     // take the first aggregation context that as that is the input series
                     let mut ac = acs.swap_remove(0);
                     ac.with_update_groups(UpdateGroups::WithGroupsLen);
-                    ac.with_series(s, true);
+                    ac.with_series(s, true, Some(&self.expr))?;
                     Ok(ac)
                 }
 
@@ -235,14 +273,15 @@ impl PhysicalExpr for ApplyExpr {
                         ApplyOptions::ApplyFlat,
                         AggState::AggregatedFlat(_) | AggState::NotAggregated(_),
                     ) = (
-                        state.overlapping_groups(),
+                        state.has_overlapping_groups(),
                         self.collect_groups,
                         acs[0].agg_state(),
                     ) {
                         apply_multiple_flat(acs, self.function.as_ref(), &self.expr)
                     } else {
                         let mut container = vec![Default::default(); acs.len()];
-                        let name = acs[0].series().name().to_string();
+                        let schema = self.get_input_schema(df);
+                        let field = self.to_field(&schema)?;
 
                         // aggregate representation of the aggregation contexts
                         // then unpack the lists and finally create iterators from this list chunked arrays.
@@ -254,25 +293,35 @@ impl PhysicalExpr for ApplyExpr {
                         // length of the items to iterate over
                         let len = iters[0].size_hint().0;
 
+                        if len == 0 {
+                            let out = Series::full_null(field.name(), 0, &field.dtype);
+
+                            drop(iters);
+                            // take the first aggregation context that as that is the input series
+                            let mut ac = acs.swap_remove(0);
+                            ac.with_series(out, true, Some(&self.expr))?;
+                            return Ok(ac);
+                        }
+
                         let mut ca: ListChunked = (0..len)
                             .map(|_| {
                                 container.clear();
                                 for iter in &mut iters {
                                     match iter.next().unwrap() {
-                                        None => return None,
+                                        None => return Ok(None),
                                         Some(s) => container.push(s.deep_clone()),
                                     }
                                 }
-                                self.function.call_udf(&mut container).ok()
+                                self.function.call_udf(&mut container)
                             })
-                            .collect_trusted();
-                        ca.rename(&name);
+                            .collect::<PolarsResult<_>>()?;
+
+                        ca.rename(&field.name);
                         drop(iters);
 
                         // take the first aggregation context that as that is the input series
                         let ac = acs.swap_remove(0);
-                        let ac = self.finish_apply_groups(ac, ca);
-                        Ok(ac)
+                        self.finish_apply_groups(ac, ca)
                     }
                 }
                 (_, ApplyOptions::ApplyFlat) => {
@@ -329,12 +378,12 @@ fn apply_multiple_flat<'a>(
         .collect::<Vec<_>>();
 
     let input_len = s[0].len();
-    let s = function.call_udf(&mut s)?;
+    let s = function.call_udf(&mut s)?.unwrap();
     check_map_output_len(input_len, s.len(), expr)?;
 
     // take the first aggregation context that as that is the input series
     let mut ac = acs.swap_remove(0);
-    ac.with_series(s, false);
+    ac.with_series(s, false, None)?;
     Ok(ac)
 }
 
@@ -377,10 +426,10 @@ impl PartitionedAggregation for ApplyExpr {
         let s = a.evaluate_partitioned(df, groups, state)?;
 
         if self.allow_rename {
-            return self.function.call_udf(&mut [s]);
+            return self.eval_and_flatten(&mut [s]);
         }
         let in_name = s.name().to_string();
-        let mut out = self.function.call_udf(&mut [s])?;
+        let mut out = self.eval_and_flatten(&mut [s])?;
         if in_name != out.name() {
             out.rename(&in_name);
         }
