@@ -11,7 +11,7 @@ fn test_agg_exprs() -> PolarsResult<()> {
         .lazy()
         .groupby_stable([col("cars")])
         .agg([(lit(1) - col("A"))
-            .map(|s| Ok(&s * 2), GetOutput::same_type())
+            .map(|s| Ok(Some(&s * 2)), GetOutput::same_type())
             .alias("foo")])
         .collect()?;
     let ca = out.column("foo")?.list()?;
@@ -181,7 +181,6 @@ fn test_power_in_agg_list1() -> PolarsResult<()> {
             },
         )
         .collect()?;
-    dbg!(&out);
 
     let agg = out.column("foo")?.list()?;
     let first = agg.get(0).unwrap();
