@@ -88,7 +88,7 @@ fn test_lazy_udf() {
     let df = get_df();
     let new = df
         .lazy()
-        .select([col("sepal.width").map(|s| Ok(s * 200.0), GetOutput::same_type())])
+        .select([col("sepal.width").map(|s| Ok(Some(s * 200.0)), GetOutput::same_type())])
         .collect()
         .unwrap();
     assert_eq!(
@@ -220,7 +220,7 @@ fn test_lazy_query_2() {
     let df = load_df();
     let ldf = df
         .lazy()
-        .with_column(col("a").map(|s| Ok(s * 2), GetOutput::same_type()))
+        .with_column(col("a").map(|s| Ok(Some(s * 2)), GetOutput::same_type()))
         .filter(col("a").lt(lit(2)))
         .select([col("b"), col("a")]);
 
@@ -255,7 +255,10 @@ fn test_lazy_query_4() {
         .agg([
             col("day").alias("day"),
             col("cumcases")
-                .apply(|s: Series| Ok(&s - &(s.shift(1))), GetOutput::same_type())
+                .apply(
+                    |s: Series| Ok(Some(&s - &(s.shift(1)))),
+                    GetOutput::same_type(),
+                )
                 .alias("diff_cases"),
         ])
         .explode([col("day"), col("diff_cases")])
@@ -688,7 +691,7 @@ fn test_lazy_groupby_apply() {
     df.lazy()
         .groupby([col("fruits")])
         .agg([col("cars").apply(
-            |s: Series| Ok(Series::new("", &[s.len() as u32])),
+            |s: Series| Ok(Some(Series::new("", &[s.len() as u32]))),
             GetOutput::same_type(),
         )])
         .collect()
@@ -1012,7 +1015,7 @@ fn test_groupby_cumsum() -> PolarsResult<()> {
 }
 
 #[test]
-fn test_argsort_multiple() -> PolarsResult<()> {
+fn test_arg_sort_multiple() -> PolarsResult<()> {
     let df = df![
         "int" => [1, 2, 3, 1, 2],
         "flt" => [3.0, 2.0, 1.0, 2.0, 1.0],
@@ -1022,7 +1025,7 @@ fn test_argsort_multiple() -> PolarsResult<()> {
     let out = df
         .clone()
         .lazy()
-        .select([argsort_by([col("int"), col("flt")], &[true, false])])
+        .select([arg_sort_by([col("int"), col("flt")], &[true, false])])
         .collect()?;
 
     assert_eq!(
@@ -1037,7 +1040,7 @@ fn test_argsort_multiple() -> PolarsResult<()> {
     // check if this runs
     let _out = df
         .lazy()
-        .select([argsort_by([col("str"), col("flt")], &[true, false])])
+        .select([arg_sort_by([col("str"), col("flt")], &[true, false])])
         .collect()?;
     Ok(())
 }
@@ -1156,32 +1159,6 @@ fn test_cross_join() -> PolarsResult<()> {
     Ok(())
 }
 
-#[test]
-fn test_fold_wildcard() -> PolarsResult<()> {
-    let df1 = df![
-    "a" => [1, 2, 3],
-    "b" => [1, 2, 3]
-    ]?;
-
-    let out = df1
-        .clone()
-        .lazy()
-        .select([fold_exprs(lit(0), |a, b| Ok(&a + &b), [col("*")]).alias("foo")])
-        .collect()?;
-
-    assert_eq!(
-        Vec::from(out.column("foo")?.i32()?),
-        &[Some(2), Some(4), Some(6)]
-    );
-
-    // test if we don't panic due to wildcard
-    let _out = df1
-        .lazy()
-        .select([all_exprs([col("*").is_not_null()])])
-        .collect()?;
-    Ok(())
-}
-
 #[test]
 fn test_select_empty_df() -> PolarsResult<()> {
     // https://github.com/pola-rs/polars/issues/1056
@@ -1250,41 +1227,6 @@ fn test_regex_selection() -> PolarsResult<()> {
     Ok(())
 }
 
-#[test]
-fn test_filter_in_groupby_agg() -> PolarsResult<()> {
-    // This tests if the filter is correctly handled by the binary expression.
-    // This could lead to UB if it were not the case. The filter creates an empty column.
-    // but the group tuples could still be untouched leading to out of bounds aggregation.
-    let df = df![
-        "a" => [1, 1, 2],
-        "b" => [1, 2, 3]
-    ]?;
-
-    let out = df
-        .clone()
-        .lazy()
-        .groupby([col("a")])
-        .agg([(col("b").filter(col("b").eq(lit(100))) * lit(2))
-            .mean()
-            .alias("b_mean")])
-        .collect()?;
-
-    assert_eq!(out.column("b_mean")?.null_count(), 2);
-
-    let out = df
-        .lazy()
-        .groupby([col("a")])
-        .agg([(col("b")
-            .filter(col("b").eq(lit(100)))
-            .map(Ok, GetOutput::same_type()))
-        .mean()
-        .alias("b_mean")])
-        .collect()?;
-    assert_eq!(out.column("b_mean")?.null_count(), 2);
-
-    Ok(())
-}
-
 #[test]
 fn test_sort_by() -> PolarsResult<()> {
     let df = df![
@@ -1648,7 +1590,7 @@ pub fn test_select_by_dtypes() -> PolarsResult<()> {
         .lazy()
         .select([dtype_cols([DataType::Float32, DataType::Utf8])])
         .collect()?;
-    assert_eq!(out.dtypes(), &[DataType::Float32, DataType::Utf8]);
+    assert_eq!(out.dtypes(), &[DataType::Utf8, DataType::Float32]);
 
     Ok(())
 }
@@ -1678,35 +1620,9 @@ fn test_binary_expr() -> PolarsResult<()> {
     Ok(())
 }
 
-#[test]
-fn test_drop_and_select() -> PolarsResult<()> {
-    let df = fruits_cars();
-
-    // we test that the schema is still correct for drop to work.
-    // typically the projection is pushed to before the drop and then the drop may think that some
-    // columns are still there to be projected
-
-    // we test this on both dataframe scan and csv scan.
-    let out = df
-        .lazy()
-        .drop_columns(["A", "B"])
-        .select([col("fruits")])
-        .collect()?;
-
-    assert_eq!(out.get_column_names(), &["fruits"]);
-
-    let out = scan_foods_csv()
-        .drop_columns(["calories", "sugar_g"])
-        .select([col("category")])
-        .collect()?;
-
-    assert_eq!(out.get_column_names(), &["category"]);
-    Ok(())
-}
-
 #[test]
 fn test_single_group_result() -> PolarsResult<()> {
-    // the argsort should not auto explode
+    // the arg_sort should not auto explode
     let df = df![
         "a" => [1, 2],
         "b" => [1, 1]
