@@ -135,7 +135,7 @@ impl GenericBuild {
     fn is_empty(&self) -> bool {
         match self.chunks.len() {
             0 => true,
-            1 => self.chunks[0].data.height() == 0,
+            1 => self.chunks[0].is_empty(),
             _ => false,
         }
     }
@@ -151,6 +151,7 @@ impl GenericBuild {
         chunk: &DataChunk,
     ) -> PolarsResult<&[Series]> {
         self.join_series.clear();
+
         for phys_e in self.join_columns_left.iter() {
             let s = phys_e.evaluate(chunk, context.execution_state.as_any())?;
             let s = s.to_physical_repr();
@@ -188,7 +189,7 @@ impl Sink for GenericBuild {
         // end up with empty chunks
         // But we always want one empty chunk if all is empty as we need
         // to finish the join
-        if self.chunks.len() == 1 && self.chunks[0].data.height() == 0 {
+        if self.chunks.len() == 1 && self.chunks[0].is_empty() {
             self.chunks.pop().unwrap();
         }
         if chunk.is_empty() {
@@ -246,7 +247,9 @@ impl Sink for GenericBuild {
     fn combine(&mut self, mut other: Box<dyn Sink>) {
         if self.is_empty() {
             let other = other.as_any().downcast_mut::<Self>().unwrap();
-            std::mem::swap(self, other);
+            if !other.is_empty() {
+                std::mem::swap(self, other);
+            }
             return;
         }
         let other = other.as_any().downcast_ref::<Self>().unwrap();
@@ -337,7 +340,7 @@ impl Sink for GenericBuild {
                 let suffix = self.suffix.clone();
                 let hb = self.hb.clone();
                 let hash_tables = Arc::new(std::mem::take(&mut self.hash_tables));
-                let join_columns_left = self.join_columns_right.clone();
+                let join_columns_left = self.join_columns_left.clone();
                 let join_columns_right = self.join_columns_right.clone();
 
                 // take the buffers, this saves one allocation
@@ -369,6 +372,9 @@ impl Sink for GenericBuild {
     fn as_any(&mut self) -> &mut dyn Any {
         self
     }
+    fn fmt(&self) -> &str {
+        "generic_join_build"
+    }
 }
 
 pub(super) struct KeysIter<'a> {
