@@ -1,16 +1,16 @@
+#[cfg(feature = "parquet")]
+mod file_sink;
 pub(crate) mod groupby;
 mod joins;
 mod ordered;
-#[cfg(feature = "parquet")]
-mod parquet_sink;
 mod slice;
 mod sort;
 mod utils;
 
+#[cfg(any(feature = "parquet", feature = "ipc"))]
+pub(crate) use file_sink::*;
 pub(crate) use joins::*;
 pub(crate) use ordered::*;
-#[cfg(feature = "parquet")]
-pub(crate) use parquet_sink::ParquetSink;
 pub(crate) use slice::*;
 pub(crate) use sort::*;
 
