@@ -102,7 +102,7 @@ pub enum FunctionExpr {
     #[cfg(feature = "top_k")]
     TopK {
         k: usize,
-        reverse: bool,
+        descending: bool,
     },
     Shift(i64),
     Reverse,
@@ -347,6 +347,9 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
                     Get => wrap!(list::get),
                     #[cfg(feature = "list_take")]
                     Take(null_ob_oob) => map_as_slice!(list::take, null_ob_oob),
+                    #[cfg(feature = "list_count")]
+                    CountMatch => map_as_slice!(list::count_match),
+                    Sum => map!(list::sum),
                 }
             }
             #[cfg(feature = "dtype-struct")]
@@ -358,8 +361,8 @@ impl From<FunctionExpr> for SpecialEq<Arc<dyn SeriesUdf>> {
                 }
             }
             #[cfg(feature = "top_k")]
-            TopK { k, reverse } => {
-                map!(top_k, k, reverse)
+            TopK { k, descending } => {
+                map!(top_k, k, descending)
             }
             Shift(periods) => map!(dispatch::shift, periods),
             Reverse => map!(dispatch::reverse),
