@@ -125,6 +125,7 @@ impl LogicalPlanBuilder {
         rechunk: bool,
         low_memory: bool,
         cloud_options: Option<CloudOptions>,
+        use_statistics: bool,
     ) -> PolarsResult<Self> {
         use polars_io::{is_cloud_url, SerReader as _};
 
@@ -170,6 +171,7 @@ impl LogicalPlanBuilder {
                 rechunk,
                 file_counter: Default::default(),
                 low_memory,
+                use_statistics,
             },
             cloud_options,
         }
@@ -556,14 +558,14 @@ impl LogicalPlanBuilder {
         .into()
     }
 
-    pub fn sort(self, by_column: Vec<Expr>, reverse: Vec<bool>, null_last: bool) -> Self {
+    pub fn sort(self, by_column: Vec<Expr>, descending: Vec<bool>, null_last: bool) -> Self {
         let schema = try_delayed!(self.0.schema(), &self.0, into);
         let by_column = try_delayed!(rewrite_projections(by_column, &schema, &[]), &self.0, into);
         LogicalPlan::Sort {
             input: Box::new(self.0),
             by_column,
             args: SortArguments {
-                reverse,
+                descending,
                 nulls_last: null_last,
                 slice: None,
             },
