@@ -36,7 +36,7 @@ pub struct CsvParserOptions {
     pub rechunk: bool,
     pub encoding: CsvEncoding,
     pub row_count: Option<RowCount>,
-    pub parse_dates: bool,
+    pub try_parse_dates: bool,
     pub file_counter: FileCount,
 }
 
@@ -52,6 +52,7 @@ pub struct ParquetOptions {
     pub row_count: Option<RowCount>,
     pub file_counter: FileCount,
     pub low_memory: bool,
+    pub use_statistics: bool,
 }
 
 #[cfg(feature = "parquet")]
@@ -253,7 +254,7 @@ pub struct LogicalPlanUdfOptions {
 #[derive(Clone, PartialEq, Eq, Debug)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct SortArguments {
-    pub reverse: Vec<bool>,
+    pub descending: Vec<bool>,
     // Can only be true in case of a single column.
     pub nulls_last: bool,
     pub slice: Option<(i64, usize)>,
