@@ -259,6 +259,7 @@ pub trait Utf8Methods: AsUtf8 {
         &self,
         fmt: Option<&str>,
         tu: TimeUnit,
+        tz: Option<&TimeZone>,
     ) -> PolarsResult<DatetimeChunked> {
         let utf8_ca = self.as_utf8();
         let fmt = match fmt {
@@ -303,7 +304,11 @@ pub trait Utf8Methods: AsUtf8 {
             })
             .collect_trusted();
         ca.rename(utf8_ca.name());
-        Ok(ca.into_datetime(tu, None))
+        match tz {
+            #[cfg(feature = "timezones")]
+            Some(tz) => ca.into_datetime(tu, None).replace_time_zone(Some(tz)),
+            _ => Ok(ca.into_datetime(tu, None)),
+        }
     }
 
     #[cfg(feature = "dtype-date")]
@@ -388,17 +393,15 @@ pub trait Utf8Methods: AsUtf8 {
         fmt: Option<&str>,
         tu: TimeUnit,
         cache: bool,
-        mut tz_aware: bool,
+        tz_aware: bool,
+        _utc: bool,
+        tz: Option<&TimeZone>,
     ) -> PolarsResult<DatetimeChunked> {
         let utf8_ca = self.as_utf8();
         let fmt = match fmt {
             Some(fmt) => fmt,
-            None => return infer::to_datetime(utf8_ca, tu),
+            None => return infer::to_datetime(utf8_ca, tu, tz),
         };
-        // todo! use regex?
-        if fmt.contains("%z") || fmt.contains("%:z") || fmt.contains("%#z") || fmt == "%+" {
-            tz_aware = true;
-        }
         let fmt = self::strptime::compile_fmt(fmt);
         let cache = cache && utf8_ca.len() > 50;
 
@@ -418,13 +421,15 @@ pub trait Utf8Methods: AsUtf8 {
 
                 let mut convert = |s: &str| {
                     DateTime::parse_from_str(s, &fmt).ok().map(|dt| {
-                        match tz {
-                            None => tz = Some(dt.timezone()),
-                            Some(tz_found) => {
-                                if tz_found != dt.timezone() {
-                                    return Err(PolarsError::ComputeError(
-                                        "Different timezones found during 'strptime' operation.".into(),
-                                    ));
+                        if !_utc {
+                            match tz {
+                                None => tz = Some(dt.timezone()),
+                                Some(tz_found) => {
+                                    if tz_found != dt.timezone() {
+                                        return Err(PolarsError::ComputeError(
+                                            "Different timezones found during 'strptime' operation. You might want to use `utc=True` and then set the time zone after parsing".into()
+                                        ));
+                                    }
                                 }
                             }
                         }
@@ -456,9 +461,13 @@ pub trait Utf8Methods: AsUtf8 {
                     })
                     .collect::<PolarsResult<_>>()?;
 
-                let tz = tz.map(|of| format!("{of}"));
                 ca.rename(utf8_ca.name());
-                Ok(ca.into_datetime(tu, tz))
+                if !_utc {
+                    let tz = tz.map(|of| format!("{of}"));
+                    Ok(ca.into_datetime(tu, tz))
+                } else {
+                    Ok(ca.into_datetime(tu, Some("UTC".to_string())))
+                }
             }
             #[cfg(not(feature = "timezones"))]
             {
@@ -519,7 +528,11 @@ pub trait Utf8Methods: AsUtf8 {
                         .collect_trusted()
                 };
             ca.rename(utf8_ca.name());
-            Ok(ca.into_datetime(tu, None))
+            match tz {
+                #[cfg(feature = "timezones")]
+                Some(tz) => ca.into_datetime(tu, None).replace_time_zone(Some(tz)),
+                _ => Ok(ca.into_datetime(tu, None)),
+            }
         }
     }
 }
