@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 from contextlib import suppress
 from dataclasses import astuple, is_dataclass
 from datetime import date, datetime, time, timedelta
@@ -62,6 +63,12 @@ from polars.utils import (
     threadpool_size,
 )
 
+with contextlib.suppress(ImportError):  # Module not available when building docs
+    from polars.polars import PyDataFrame, PySeries
+
+if TYPE_CHECKING:
+    from polars.internals.type_aliases import Orientation
+
 if version_info >= (3, 10):
 
     def dataclass_type_hints(obj: type) -> dict[str, Any]:
@@ -73,18 +80,6 @@ else:
         return obj.__annotations__
 
 
-try:
-    from polars.polars import PyDataFrame, PySeries
-
-    _DOCUMENTING = False
-except ImportError:
-    _DOCUMENTING = True
-
-
-if TYPE_CHECKING:
-    from polars.internals.type_aliases import Orientation
-
-
 def is_namedtuple(value: Any, annotated: bool = False) -> bool:
     """Infer whether value is a NamedTuple."""
     if all(hasattr(value, attr) for attr in ("_fields", "_field_defaults", "_replace")):
@@ -145,7 +140,7 @@ def arrow_to_pyseries(name: str, values: pa.Array, rechunk: bool = True) -> PySe
         elif array.num_chunks == 0:
             pys = PySeries.from_arrow(name, pa.array([], array.type))
         else:
-            pys = PySeries.from_arrow(name, array.combine_chunks())
+            pys = PySeries.from_arrow(name, array.chunks[0])
 
         if rechunk:
             pys.rechunk(in_place=True)
@@ -365,7 +360,7 @@ def sequence_to_pyseries(
                     nan_to_null=nan_to_null,
                     strict=strict,
                 )
-                return s if values else pli.Series._from_pyseries(s)[:0]._s
+                return s if values else pli.Series._from_pyseries(s).head(0)._s
 
             # logs will show a panic if we infer wrong dtype and it's hard to error
             # from the rust side. to reduce the likelihood of this happening we
