@@ -1,21 +1,19 @@
 from __future__ import annotations
 
-import sys
-import typing
+import contextlib
 from datetime import date, datetime, timedelta
-from typing import TYPE_CHECKING, Sequence, overload
+from typing import TYPE_CHECKING, Iterable, Sequence, overload
 
 from polars import internals as pli
 from polars.datatypes import Categorical, Date, Float64, PolarsDataType
-from polars.utils import _datetime_to_pl_timestamp, _timedelta_to_pl_duration
+from polars.utils import (
+    _datetime_to_pl_timestamp,
+    _timedelta_to_pl_duration,
+    deprecate_nonkeyword_arguments,
+    deprecated_alias,
+)
 
-if sys.version_info >= (3, 10):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
-try:
+with contextlib.suppress(ImportError):  # Module not available when building docs
     from polars.polars import concat_df as _concat_df
     from polars.polars import concat_lf as _concat_lf
     from polars.polars import concat_series as _concat_series
@@ -25,16 +23,23 @@ try:
     from polars.polars import py_diag_concat_lf as _diag_concat_lf
     from polars.polars import py_hor_concat_df as _hor_concat_df
 
-    _DOCUMENTING = False
-except ImportError:
-    _DOCUMENTING = True
 
 if TYPE_CHECKING:
-    from polars.internals.type_aliases import ClosedWindow, ConcatMethod, TimeUnit
+    import sys
+
+    from polars.internals.type_aliases import ClosedInterval, ConcatMethod, TimeUnit
+
+    if sys.version_info >= (3, 8):
+        from typing import Literal
+    else:
+        from typing_extensions import Literal
 
 
 def get_dummies(
-    df: pli.DataFrame, *, columns: list[str] | None = None
+    df: pli.DataFrame,
+    *,
+    columns: str | Sequence[str] | None = None,
+    separator: str = "_",
 ) -> pli.DataFrame:
     """
     Convert categorical variables into dummy/indicator variables.
@@ -44,8 +49,10 @@ def get_dummies(
     df
         DataFrame to convert.
     columns
-        A subset of columns to convert to dummy variables. ``None`` means
-        "all columns".
+        Name of the column(s) that should be converted to dummy variables.
+        If set to ``None`` (default), convert all columns.
+    separator
+        Separator/delimiter used when generating column names.
 
     Examples
     --------
@@ -64,17 +71,16 @@ def get_dummies(
     │ u8    ┆ u8    ┆ u8    ┆ u8    ┆ u8    ┆ u8    │
     ╞═══════╪═══════╪═══════╪═══════╪═══════╪═══════╡
     │ 1     ┆ 0     ┆ 1     ┆ 0     ┆ 1     ┆ 0     │
-    ├╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
     │ 0     ┆ 1     ┆ 0     ┆ 1     ┆ 0     ┆ 1     │
     └───────┴───────┴───────┴───────┴───────┴───────┘
 
     """
-    return df.to_dummies(columns=columns)
+    return df.to_dummies(columns=columns, separator=separator)
 
 
 @overload
 def concat(
-    items: Sequence[pli.DataFrame],
+    items: Iterable[pli.DataFrame],
     rechunk: bool = True,
     how: ConcatMethod = "vertical",
     parallel: bool = True,
@@ -84,7 +90,7 @@ def concat(
 
 @overload
 def concat(
-    items: Sequence[pli.Series],
+    items: Iterable[pli.Series],
     rechunk: bool = True,
     how: ConcatMethod = "vertical",
     parallel: bool = True,
@@ -94,7 +100,7 @@ def concat(
 
 @overload
 def concat(
-    items: Sequence[pli.LazyFrame],
+    items: Iterable[pli.LazyFrame],
     rechunk: bool = True,
     how: ConcatMethod = "vertical",
     parallel: bool = True,
@@ -104,7 +110,7 @@ def concat(
 
 @overload
 def concat(
-    items: Sequence[pli.Expr],
+    items: Iterable[pli.Expr],
     rechunk: bool = True,
     how: ConcatMethod = "vertical",
     parallel: bool = True,
@@ -112,12 +118,13 @@ def concat(
     ...
 
 
+@deprecate_nonkeyword_arguments()
 def concat(
     items: (
-        Sequence[pli.DataFrame]
-        | Sequence[pli.Series]
-        | Sequence[pli.LazyFrame]
-        | Sequence[pli.Expr]
+        Iterable[pli.DataFrame]
+        | Iterable[pli.Series]
+        | Iterable[pli.LazyFrame]
+        | Iterable[pli.Expr]
     ),
     rechunk: bool = True,
     how: ConcatMethod = "vertical",
@@ -156,7 +163,6 @@ def concat(
     │ i64 ┆ i64 │
     ╞═════╪═════╡
     │ 1   ┆ 3   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   │
     └─────┴─────┘
 
@@ -187,7 +193,6 @@ def concat(
     │ i64 ┆ i64 ┆ i64 ┆ i64 ┆ i64 │
     ╞═════╪═════╪═════╪═════╪═════╡
     │ 1   ┆ 3   ┆ 5   ┆ 7   ┆ 9   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   ┆ 6   ┆ 8   ┆ 10  │
     └─────┴─────┴─────┴─────┴─────┘
 
@@ -217,23 +222,25 @@ def concat(
     │ i64 ┆ i64  ┆ i64  │
     ╞═════╪══════╪══════╡
     │ 1   ┆ 3    ┆ null │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ 2   ┆ null ┆ 4    │
     └─────┴──────┴──────┘
 
     """
-    if not len(items) > 0:
+    # unpack/standardise (offers simple support for generator input)
+    elems = list(items)
+
+    if not len(elems) > 0:
         raise ValueError("cannot concat empty list")
 
     out: pli.Series | pli.DataFrame | pli.LazyFrame | pli.Expr
-    first = items[0]
+    first = elems[0]
     if isinstance(first, pli.DataFrame):
         if how == "vertical":
-            out = pli.wrap_df(_concat_df(items))
+            out = pli.wrap_df(_concat_df(elems))
         elif how == "diagonal":
-            out = pli.wrap_df(_diag_concat_df(items))
+            out = pli.wrap_df(_diag_concat_df(elems))
         elif how == "horizontal":
-            out = pli.wrap_df(_hor_concat_df(items))
+            out = pli.wrap_df(_hor_concat_df(elems))
         else:
             raise ValueError(
                 f"how must be one of {{'vertical', 'diagonal', 'horizontal'}}, "
@@ -241,18 +248,18 @@ def concat(
             )
     elif isinstance(first, pli.LazyFrame):
         if how == "vertical":
-            return pli.wrap_ldf(_concat_lf(items, rechunk, parallel))
+            return pli.wrap_ldf(_concat_lf(elems, rechunk, parallel))
         if how == "diagonal":
-            return pli.wrap_ldf(_diag_concat_lf(items, rechunk, parallel))
+            return pli.wrap_ldf(_diag_concat_lf(elems, rechunk, parallel))
         else:
             raise ValueError(
                 "Lazy only allows {{'vertical', 'diagonal'}} concat strategy."
             )
     elif isinstance(first, pli.Series):
-        out = pli.wrap_s(_concat_series(items))
+        out = pli.wrap_s(_concat_series(elems))
     elif isinstance(first, pli.Expr):
         out = first
-        for e in items[1:]:
+        for e in elems[1:]:
             out = out.append(e)  # type: ignore[arg-type]
     else:
         raise ValueError(f"did not expect type: {type(first)} in 'pl.concat'.")
@@ -278,13 +285,13 @@ def _interval_granularity(interval: str) -> str:
 def date_range(
     low: pli.Expr,
     high: date | datetime | pli.Expr | str,
-    interval: str | timedelta,
+    interval: str | timedelta = ...,
     *,
     lazy: Literal[False] = ...,
-    closed: ClosedWindow = "both",
-    name: str | None = None,
-    time_unit: TimeUnit | None = None,
-    time_zone: str | None = None,
+    closed: ClosedInterval = ...,
+    name: str | None = ...,
+    time_unit: TimeUnit | None = ...,
+    time_zone: str | None = ...,
 ) -> pli.Expr:
     ...
 
@@ -293,13 +300,13 @@ def date_range(
 def date_range(
     low: date | datetime | pli.Expr | str,
     high: pli.Expr,
-    interval: str | timedelta,
+    interval: str | timedelta = ...,
     *,
     lazy: Literal[False] = ...,
-    closed: ClosedWindow = "both",
-    name: str | None = None,
-    time_unit: TimeUnit | None = None,
-    time_zone: str | None = None,
+    closed: ClosedInterval = ...,
+    name: str | None = ...,
+    time_unit: TimeUnit | None = ...,
+    time_zone: str | None = ...,
 ) -> pli.Expr:
     ...
 
@@ -308,13 +315,13 @@ def date_range(
 def date_range(
     low: date | datetime | str,
     high: date | datetime | str,
-    interval: str | timedelta,
+    interval: str | timedelta = ...,
     *,
     lazy: Literal[False] = ...,
-    closed: ClosedWindow = "both",
-    name: str | None = None,
-    time_unit: TimeUnit | None = None,
-    time_zone: str | None = None,
+    closed: ClosedInterval = ...,
+    name: str | None = ...,
+    time_unit: TimeUnit | None = ...,
+    time_zone: str | None = ...,
 ) -> pli.Series:
     ...
 
@@ -323,25 +330,24 @@ def date_range(
 def date_range(
     low: date | datetime | pli.Expr | str,
     high: date | datetime | pli.Expr | str,
-    interval: str | timedelta,
+    interval: str | timedelta = ...,
     *,
     lazy: Literal[True],
-    closed: ClosedWindow = "both",
+    closed: ClosedInterval = ...,
     name: str | None = None,
-    time_unit: TimeUnit | None = None,
-    time_zone: str | None = None,
+    time_unit: TimeUnit | None = ...,
+    time_zone: str | None = ...,
 ) -> pli.Expr:
     ...
 
 
-@typing.no_type_check
 def date_range(
     low: date | datetime | pli.Expr | str,
     high: date | datetime | pli.Expr | str,
-    interval: str | timedelta,
+    interval: str | timedelta = "1d",
     *,
     lazy: bool = False,
-    closed: ClosedWindow = "both",
+    closed: ClosedInterval = "both",
     name: str | None = None,
     time_unit: TimeUnit | None = None,
     time_zone: str | None = None,
@@ -352,9 +358,9 @@ def date_range(
     Parameters
     ----------
     low
-        Lower bound of the date range.
+        Lower bound of the date range, given as a date, datetime, Expr, or column name.
     high
-        Upper bound of the date range.
+        Upper bound of the date range, given as a date, datetime, Expr, or column name.
     interval
         Interval periods. It can be a python timedelta object, like
         ``timedelta(days=10)``, or a polars duration string, such as ``3d12h4m25s``
@@ -440,9 +446,9 @@ def date_range(
     elif " " in interval:
         interval = interval.replace(" ", "")
 
-    if isinstance(low, pli.Expr) or isinstance(high, pli.Expr) or lazy:
-        low = pli.expr_to_lit_or_expr(low, str_to_lit=True)._pyexpr
-        high = pli.expr_to_lit_or_expr(high, str_to_lit=True)._pyexpr
+    if isinstance(low, (str, pli.Expr)) or isinstance(high, (str, pli.Expr)) or lazy:
+        low = pli.expr_to_lit_or_expr(low, str_to_lit=False)._pyexpr
+        high = pli.expr_to_lit_or_expr(high, str_to_lit=False)._pyexpr
         return pli.wrap_expr(
             _py_date_range_lazy(low, high, interval, closed, name, time_zone)
         )
@@ -533,21 +539,13 @@ def cut(
     │ f64  ┆ f64         ┆ cat          │
     ╞══════╪═════════════╪══════════════╡
     │ -3.0 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -2.5 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -2.0 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -1.5 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ ...  ┆ ...         ┆ ...          │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 1.0  ┆ 1.0         ┆ (-1.0, 1.0]  │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 1.5  ┆ inf         ┆ (1.0, inf]   │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2.0  ┆ inf         ┆ (1.0, inf]   │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2.5  ┆ inf         ┆ (1.0, inf]   │
     └──────┴─────────────┴──────────────┘
 
@@ -565,9 +563,9 @@ def cut(
     if labels:
         if len(labels) != len(bins) + 1:
             raise ValueError("expected more labels")
-        cuts_df = cuts_df.with_column(pli.Series(name=category_label, values=labels))
+        cuts_df = cuts_df.with_columns(pli.Series(name=category_label, values=labels))
     else:
-        cuts_df = cuts_df.with_column(
+        cuts_df = cuts_df.with_columns(
             pli.format(
                 "({}, {}]",
                 pli.col(break_point_label).shift_and_fill(1, float("-inf")),
@@ -575,7 +573,7 @@ def cut(
             ).alias(category_label)
         )
 
-    cuts_df = cuts_df.with_column(pli.col(category_label).cast(Categorical))
+    cuts_df = cuts_df.with_columns(pli.col(category_label).cast(Categorical))
 
     result = (
         s.cast(Float64)
@@ -596,7 +594,7 @@ def align_frames(
     *frames: pli.DataFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
-    reverse: bool | Sequence[bool] = False,
+    descending: bool | Sequence[bool] = False,
 ) -> list[pli.DataFrame]:
     ...
 
@@ -606,16 +604,17 @@ def align_frames(
     *frames: pli.LazyFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
-    reverse: bool | Sequence[bool] = False,
+    descending: bool | Sequence[bool] = False,
 ) -> list[pli.LazyFrame]:
     ...
 
 
+@deprecated_alias(reverse="descending")
 def align_frames(
     *frames: pli.DataFrame | pli.LazyFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
-    reverse: bool | Sequence[bool] = False,
+    descending: bool | Sequence[bool] = False,
 ) -> list[pli.DataFrame] | list[pli.LazyFrame]:
     r"""
     Align a sequence of frames using the unique values from one or more columns as a key.
@@ -639,7 +638,7 @@ def align_frames(
     select
         optional post-alignment column select to constrain and/or order
         the columns returned from the newly aligned frames.
-    reverse
+    descending
         sort the alignment column values in descending order; can be a single
         boolean or a list of booleans associated with each column in ``on``.
 
@@ -666,6 +665,8 @@ def align_frames(
     ...         "y": [2.5, 2.0],
     ...     }
     ... )  # doctest: +IGNORE_RESULT
+    >>>
+    >>> pl.Config.set_tbl_formatting("UTF8_FULL")  # doctest: +IGNORE_RESULT
     #
     # df1                              df2                              df3
     # shape: (3, 3)                    shape: (3, 3)                    shape: (2, 3)
@@ -734,7 +735,7 @@ def align_frames(
     │ 47.0  │
     └───────┘
 
-    """  # noqa: E501
+    """  # noqa: W505
     if not frames:
         return []  # type: ignore[return-value]
     elif len({type(f) for f in frames}) != 1:
@@ -747,7 +748,7 @@ def align_frames(
     alignment_frame = (
         concat([df.lazy().select(on) for df in frames])
         .unique(maintain_order=False)
-        .sort(by=on, reverse=reverse)
+        .sort(by=on, descending=descending)
     )
     alignment_frame = (
         alignment_frame.collect().lazy() if eager else alignment_frame.cache()
