@@ -1,12 +1,10 @@
+import contextlib
+
 import polars.internals as pli
 
-try:
+with contextlib.suppress(ImportError):  # Module not available when building docs
     from polars.polars import PySQLContext
 
-    _DOCUMENTING = False
-except ImportError:
-    _DOCUMENTING = True
-
 
 class SQLContext:
     """
