@@ -24,7 +24,7 @@ impl PyBatchedCsv {
         infer_schema_length, chunk_size, has_header, ignore_errors, n_rows, skip_rows,
         projection, sep, rechunk, columns, encoding, n_threads, path, overwrite_dtype,
         overwrite_dtype_slice, low_memory, comment_char, quote_char, null_values,
-        missing_utf8_is_empty_string, parse_dates, skip_rows_after_header, row_count,
+        missing_utf8_is_empty_string, try_parse_dates, skip_rows_after_header, row_count,
         sample_size, eol_char)
     )]
     fn new(
@@ -48,7 +48,7 @@ impl PyBatchedCsv {
         quote_char: Option<&str>,
         null_values: Option<Wrap<NullValues>>,
         missing_utf8_is_empty_string: bool,
-        parse_dates: bool,
+        try_parse_dates: bool,
         skip_rows_after_header: usize,
         row_count: Option<(String, IdxSize)>,
         sample_size: usize,
@@ -103,7 +103,7 @@ impl PyBatchedCsv {
             .low_memory(low_memory)
             .with_comment_char(comment_char)
             .with_null_values(null_values)
-            .with_parse_dates(parse_dates)
+            .with_try_parse_dates(try_parse_dates)
             .with_quote_char(quote_char)
             .with_end_of_line_char(eol_char)
             .with_skip_rows_after_header(skip_rows_after_header)
