@@ -113,10 +113,10 @@ impl PySeries {
 
 #[pymethods]
 impl PySeries {
-    pub fn is_sorted_flag(&self) -> bool {
+    pub fn is_sorted_ascending_flag(&self) -> bool {
         matches!(self.series.is_sorted_flag(), IsSorted::Ascending)
     }
-    pub fn is_sorted_reverse_flag(&self) -> bool {
+    pub fn is_sorted_descending_flag(&self) -> bool {
         matches!(self.series.is_sorted_flag(), IsSorted::Descending)
     }
     pub fn can_fast_explode_flag(&self) -> bool {
@@ -245,6 +245,12 @@ impl PySeries {
         PySeries::new(s)
     }
 
+    #[staticmethod]
+    pub fn new_null(name: &str, val: &PyAny, _strict: bool) -> PyResult<Self> {
+        let s = Series::new_null(name, val.len()?);
+        Ok(PySeries::new(s))
+    }
+
     #[staticmethod]
     pub fn new_object(name: &str, val: Vec<ObjectValue>, _strict: bool) -> Self {
         #[cfg(feature = "object")]
@@ -428,9 +434,9 @@ impl PySeries {
             .map(|dt| Wrap(dt.clone()).to_object(py))
     }
 
-    fn set_sorted_flag(&self, reverse: bool) -> Self {
+    fn set_sorted_flag(&self, descending: bool) -> Self {
         let mut out = self.series.clone();
-        if reverse {
+        if descending {
             out.set_sorted_flag(IsSorted::Descending);
         } else {
             out.set_sorted_flag(IsSorted::Ascending)
@@ -538,8 +544,8 @@ impl PySeries {
         (&self.series % &other.series).into()
     }
 
-    pub fn sort(&mut self, reverse: bool) -> Self {
-        PySeries::new(self.series.sort(reverse))
+    pub fn sort(&mut self, descending: bool) -> Self {
+        PySeries::new(self.series.sort(descending))
     }
 
     pub fn value_counts(&self, sorted: bool) -> PyResult<PyDataFrame> {
@@ -704,8 +710,31 @@ impl PySeries {
                         let ca = series.binary().unwrap();
                         return Wrap(ca).to_object(py);
                     }
-                    DataType::Null | DataType::Unknown => {
-                        panic!("to_list not implemented for null/unknown")
+                    DataType::Null => {
+                        let null: Option<u8> = None;
+                        let n = series.len();
+                        let iter = std::iter::repeat(null).take(n);
+                        use std::iter::{Repeat, Take};
+                        struct NullIter {
+                            iter: Take<Repeat<Option<u8>>>,
+                            n: usize,
+                        }
+                        impl Iterator for NullIter {
+                            type Item = Option<u8>;
+
+                            fn next(&mut self) -> Option<Self::Item> {
+                                self.iter.next()
+                            }
+                            fn size_hint(&self) -> (usize, Option<usize>) {
+                                (self.n, Some(self.n))
+                            }
+                        }
+                        impl ExactSizeIterator for NullIter {}
+
+                        PyList::new(py, NullIter { iter, n })
+                    }
+                    DataType::Unknown => {
+                        panic!("to_list not implemented for unknown")
                     }
                 };
                 pylist.to_object(py)
@@ -1116,10 +1145,10 @@ impl PySeries {
         })
     }
 
-    pub fn is_sorted(&self, reverse: bool) -> bool {
+    pub fn is_sorted(&self, descending: bool) -> bool {
         let options = SortOptions {
-            descending: reverse,
-            nulls_last: reverse,
+            descending,
+            nulls_last: descending,
             multithreaded: true,
         };
         self.series.is_sorted(options)
