@@ -8,14 +8,14 @@ import textwrap
 import zlib
 from datetime import date, datetime, time, timedelta, timezone
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import numpy as np
 import pytest
 
 import polars as pl
 from polars import DataType
-from polars.exceptions import NoDataError
-from polars.internals.type_aliases import TimeUnit
+from polars.exceptions import ComputeError, NoDataError
 from polars.testing import (
     assert_frame_equal,
     assert_frame_equal_local_categoricals,
@@ -23,6 +23,9 @@ from polars.testing import (
 )
 from polars.utils import normalise_filepath
 
+if TYPE_CHECKING:
+    from polars.internals.type_aliases import TimeUnit
+
 
 @pytest.fixture()
 def foods_file_path(io_files_path: Path) -> Path:
@@ -37,7 +40,7 @@ def test_quoted_date() -> None:
         "2022-01-02",2
         """
     )
-    result = pl.read_csv(csv.encode(), parse_dates=True)
+    result = pl.read_csv(csv.encode(), try_parse_dates=True)
     expected = pl.DataFrame({"a": [date(2022, 1, 1), date(2022, 1, 2)], "b": [1, 2]})
     assert_frame_equal(result, expected)
 
@@ -48,7 +51,7 @@ def test_to_from_buffer(df_no_lists: pl.DataFrame) -> None:
     df.write_csv(buf)
     buf.seek(0)
 
-    read_df = pl.read_csv(buf, parse_dates=True)
+    read_df = pl.read_csv(buf, try_parse_dates=True)
     read_df = read_df.with_columns(
         [pl.col("cat").cast(pl.Categorical), pl.col("time").cast(pl.Time)]
     )
@@ -63,7 +66,7 @@ def test_to_from_file(df_no_lists: pl.DataFrame) -> None:
     with tempfile.TemporaryDirectory() as temp_dir:
         file_path = Path(temp_dir) / "small.csv"
         df.write_csv(file_path)
-        read_df = pl.read_csv(file_path, parse_dates=True)
+        read_df = pl.read_csv(file_path, try_parse_dates=True)
 
     read_df = read_df.with_columns(
         [pl.col("cat").cast(pl.Categorical), pl.col("time").cast(pl.Time)]
@@ -250,7 +253,7 @@ def test_datetime_parsing() -> None:
     )
 
     f = io.StringIO(csv)
-    df = pl.read_csv(f, parse_dates=True)
+    df = pl.read_csv(f, try_parse_dates=True)
     assert df.dtypes == [pl.Datetime, pl.Float64, pl.Float64]
 
 
@@ -266,7 +269,7 @@ def test_datetime_parsing_default_formats() -> None:
     )
 
     f = io.StringIO(csv)
-    df = pl.read_csv(f, parse_dates=True)
+    df = pl.read_csv(f, try_parse_dates=True)
     assert df.dtypes == [pl.Datetime, pl.Datetime, pl.Datetime]
 
 
@@ -559,7 +562,7 @@ def test_csv_empty_quotes_char_1622() -> None:
     pl.read_csv(b"a,b,c,d\nA1,B1,C1,1\nA2,B2,C2,2\n", quote_char="")
 
 
-def test_ignore_parse_dates() -> None:
+def test_ignore_try_parse_dates() -> None:
     csv = textwrap.dedent(
         """\
         a,b,c
@@ -602,7 +605,7 @@ def test_csv_date_handling() -> None:
             ]
         }
     )
-    out = pl.read_csv(csv.encode(), parse_dates=True)
+    out = pl.read_csv(csv.encode(), try_parse_dates=True)
     assert_frame_equal(out, expected)
     dtypes = {"date": pl.Date}
     out = pl.read_csv(csv.encode(), dtypes=dtypes)
@@ -732,7 +735,7 @@ def test_fallback_chrono_parser() -> None:
     2021-10-10,2021-10-10
     """
     )
-    df = pl.read_csv(data.encode(), parse_dates=True)
+    df = pl.read_csv(data.encode(), try_parse_dates=True)
     assert df.null_count().row(0) == (0, 0)
 
 
@@ -870,6 +873,17 @@ def test_datetime_format(fmt: str, expected: str) -> None:
     assert csv == expected
 
 
+def test_invalid_datetime_format() -> None:
+    tz_naive = pl.Series(["2020-01-01T00:00:00"]).str.strptime(pl.Datetime)
+    tz_aware = tz_naive.dt.replace_time_zone("UTC")
+    with pytest.raises(
+        ComputeError, match="Cannot format NaiveDateTime with format '%q'."
+    ):
+        tz_naive.to_frame().write_csv(datetime_format="%q")
+    with pytest.raises(ComputeError, match="Cannot format DateTime with format '%q'."):
+        tz_aware.to_frame().write_csv(datetime_format="%q")
+
+
 @pytest.mark.parametrize(
     ("fmt", "expected"),
     [
