@@ -1,9 +1,12 @@
 from __future__ import annotations
 
+import typing
+
 import numpy as np
 import pytest
 
 import polars as pl
+from polars.testing import assert_frame_equal, assert_series_equal
 
 
 def test_date_datetime() -> None:
@@ -22,8 +25,8 @@ def test_date_datetime() -> None:
             pl.date("year", "month", "day").dt.day().cast(int).alias("date"),
         ]
     )
-    assert out["date"].series_equal(df["day"].rename("date"))
-    assert out["h2"].series_equal(df["hour"].rename("h2"))
+    assert_series_equal(out["date"], df["day"].rename("date"))
+    assert_series_equal(out["h2"], df["hour"].rename("h2"))
 
 
 def test_diag_concat() -> None:
@@ -44,7 +47,7 @@ def test_diag_concat() -> None:
             }
         )
 
-        assert out.frame_equal(expected, null_equal=True)
+        assert_frame_equal(out, expected)
 
 
 def test_concat_horizontal() -> None:
@@ -61,7 +64,7 @@ def test_concat_horizontal() -> None:
             "e": [1, 2, 1, 2],
         }
     )
-    assert out.frame_equal(expected)
+    assert_frame_equal(out, expected)
 
 
 def test_all_any_horizontally() -> None:
@@ -81,12 +84,13 @@ def test_all_any_horizontally() -> None:
             "all": [False, False, False, None, False],
         }
     )
-    assert df.select(
+    result = df.select(
         [
             pl.any([pl.col("var2"), pl.col("var3")]),
             pl.all([pl.col("var2"), pl.col("var3")]),
         ]
-    ).frame_equal(expected)
+    )
+    assert_frame_equal(result, expected)
 
 
 def test_cut() -> None:
@@ -185,7 +189,7 @@ def test_align_frames() -> None:
         .insert_at_idx(0, pf1["date"])
     )
     # confirm we match the same operation in pandas
-    assert pl_dot.frame_equal(pl.from_pandas(pd_dot))
+    assert_frame_equal(pl_dot, pl.from_pandas(pd_dot))
     pd.testing.assert_frame_equal(pd_dot, pl_dot.to_pandas())
 
     # (also: confirm alignment function works with lazyframes)
@@ -195,8 +199,8 @@ def test_align_frames() -> None:
         on="date",
     )
     assert isinstance(lf1, pl.LazyFrame)
-    assert lf1.collect().frame_equal(pf1)
-    assert lf2.collect().frame_equal(pf2)
+    assert_frame_equal(lf1.collect(), pf1)
+    assert_frame_equal(lf2.collect(), pf2)
 
     # misc
     assert [] == pl.align_frames(on="date")
@@ -209,12 +213,12 @@ def test_align_frames() -> None:
             on="date",
         )
 
-    # reverse
+    # descending
     pf1, pf2 = pl.align_frames(
         pl.DataFrame([[3, 5, 6], [5, 8, 9]], orient="row"),
         pl.DataFrame([[2, 5, 6], [3, 8, 9], [4, 2, 0]], orient="row"),
         on="column_0",
-        reverse=True,
+        descending=True,
     )
     assert pf1.rows() == [(5, 8, 9), (4, None, None), (3, 5, 6), (2, None, None)]
     assert pf2.rows() == [(5, None, None), (4, 2, 0), (3, 8, 9), (2, 5, 6)]
@@ -243,17 +247,21 @@ def test_nan_aggregations() -> None:
 def test_coalesce() -> None:
     df = pl.DataFrame(
         {
-            "a": [None, None, None, None],
+            "a": [1, None, None, None],
             "b": [1, 2, None, None],
-            "c": [1, None, 3, None],
+            "c": [5, None, 3, None],
         }
     )
-    assert df.select(pl.coalesce(["a", "b", "c", 10])).to_dict(False) == {
-        "a": [1.0, 2.0, 3.0, 10.0]
-    }
-    assert df.select(pl.coalesce(pl.col(["a", "b", "c"]))).to_dict(False) == {
-        "a": [1.0, 2.0, 3.0, None]
-    }
+
+    # List inputs
+    expected = pl.Series("d", [1, 2, 3, 10]).to_frame()
+    result = df.select(pl.coalesce(["a", "b", "c", 10]).alias("d"))
+    assert_frame_equal(expected, result)
+
+    # Positional inputs
+    expected = pl.Series("d", [1.0, 2.0, 3.0, 10.0]).to_frame()
+    result = df.select(pl.coalesce(pl.col(["a", "b", "c"]), 10.0).alias("d"))
+    assert_frame_equal(result, expected)
 
 
 def test_ones_zeros() -> None:
@@ -283,3 +291,29 @@ def test_overflow_diff() -> None:
     assert df.select(pl.col("a").cast(pl.UInt64).diff()).to_dict(False) == {
         "a": [None, -10, 20]
     }
+
+
+@typing.no_type_check
+def test_fill_null_unknown_output_type() -> None:
+    df = pl.DataFrame(
+        {
+            "a": [
+                None,
+                2,
+                3,
+                4,
+                5,
+            ]
+        }
+    )
+    assert df.with_columns(
+        np.exp(pl.col("a")).fill_null(pl.lit(1, pl.Float64))
+    ).to_dict(False) == {
+        "a": [
+            1.0,
+            7.38905609893065,
+            20.085536923187668,
+            54.598150033144236,
+            148.4131591025766,
+        ]
+    }
