@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import typing
-from datetime import datetime
+from datetime import date, datetime
 from typing import Any, cast, no_type_check
 
 import numpy as np
@@ -160,8 +160,8 @@ def test_from_pandas_nan_to_null() -> None:
 
 def test_from_pandas_datetime() -> None:
     ts = datetime(2021, 1, 1, 20, 20, 20, 20)
-    pl_s = pd.Series([ts, ts])
-    tmp = pl.from_pandas(pl_s.to_frame("a"))
+    pd_s = pd.Series([ts, ts])
+    tmp = pl.from_pandas(pd_s.to_frame("a"))
     s = tmp["a"]
     assert s.dt.hour()[0] == 20
     assert s.dt.minute()[0] == 20
@@ -172,9 +172,26 @@ def test_from_pandas_datetime() -> None:
     assert s[0] == datetime(2021, 6, 24, 0, 0)
     assert s[-1] == datetime(2021, 6, 24, 9, 0)
 
-    df = pd.DataFrame({"datetime": ["2021-01-01", "2021-01-02"], "foo": [1, 2]})
-    df["datetime"] = pd.to_datetime(df["datetime"])
-    pl.from_pandas(df)
+
+def test_from_pandas_include_indexes() -> None:
+    data = {
+        "dtm": [datetime(2021, 1, 1), datetime(2021, 1, 2), datetime(2021, 1, 3)],
+        "val": [100, 200, 300],
+        "misc": ["x", "y", "z"],
+    }
+    pd_df = pd.DataFrame(data)
+
+    df = pl.from_pandas(pd_df.set_index(["dtm"]))
+    assert df.to_dict(False) == {"val": [100, 200, 300], "misc": ["x", "y", "z"]}
+
+    df = pl.from_pandas(pd_df.set_index(["dtm", "val"]))
+    assert df.to_dict(False) == {"misc": ["x", "y", "z"]}
+
+    df = pl.from_pandas(pd_df.set_index(["dtm"]), include_index=True)
+    assert df.to_dict(False) == data
+
+    df = pl.from_pandas(pd_df.set_index(["dtm", "val"]), include_index=True)
+    assert df.to_dict(False) == data
 
 
 def test_from_pandas_duplicated_columns() -> None:
@@ -459,33 +476,51 @@ def test_cat_to_pandas() -> None:
 
 def test_to_pandas() -> None:
     df = pl.DataFrame(
-        {"a": [1, 2, 3], "b": [6, None, 8], "c": ["a", "b", "c"], "d": [None, "e", "f"]}
-    )
-    df = df.with_columns(
+        {
+            "a": [1, 2, 3],
+            "b": [6, None, 8],
+            "c": [10.0, 25.0, 50.5],
+            "d": [date(2023, 7, 5), None, date(1999, 12, 13)],
+            "e": ["a", "b", "c"],
+            "f": [None, "e", "f"],
+            "g": [datetime.now(), datetime.now(), None],
+        },
+        schema_overrides={"a": pl.UInt8},
+    ).with_columns(
         [
-            pl.col("c").cast(pl.Categorical).alias("e"),
-            pl.col("d").cast(pl.Categorical).alias("f"),
+            pl.col("e").cast(pl.Categorical).alias("h"),
+            pl.col("f").cast(pl.Categorical).alias("i"),
         ]
     )
     pd_out = df.to_pandas()
     pd_out_dtypes_expected = [
-        np.int64,
+        np.uint8,
         np.float64,
+        np.float64,
+        np.dtype("datetime64[ns]"),
         np.object_,
         np.object_,
+        np.dtype("datetime64[ns]"),
         pd.CategoricalDtype(categories=["a", "b", "c"], ordered=False),
         pd.CategoricalDtype(categories=["e", "f"], ordered=False),
     ]
-    assert pd_out.dtypes.to_list() == pd_out_dtypes_expected
+    assert pd_out_dtypes_expected == pd_out.dtypes.to_list()
+
+    pd_out_dtypes_expected[3] = np.dtype("O")
+    pd_out = df.to_pandas(date_as_object=True)
+    assert pd_out_dtypes_expected == pd_out.dtypes.to_list()
 
     try:
         pd_pa_out = df.to_pandas(use_pyarrow_extension_array=True)
         pd_pa_dtypes_names = [dtype.name for dtype in pd_pa_out.dtypes]
         pd_pa_dtypes_names_expected = [
+            "uint8[pyarrow]",
             "int64[pyarrow]",
-            "int64[pyarrow]",
+            "double[pyarrow]",
+            "date32[day][pyarrow]",
             "large_string[pyarrow]",
             "large_string[pyarrow]",
+            "timestamp[us][pyarrow]",
             "dictionary<values=large_string, indices=int64, ordered=0>[pyarrow]",
             "dictionary<values=large_string, indices=int64, ordered=0>[pyarrow]",
         ]
@@ -530,6 +565,7 @@ def test_from_empty_pandas_with_dtypes() -> None:
             "e": pl.Utf8,
         },
     ).to_pandas()
+
     assert pl.from_pandas(df).dtypes == [
         pl.Int32,
         pl.Datetime,
@@ -549,7 +585,7 @@ def test_from_empty_arrow() -> None:
     tbl = pa.Table.from_pandas(df1)
     out = cast(pl.DataFrame, pl.from_arrow(tbl))
     assert out.columns == ["b", "__index_level_0__"]
-    assert out.dtypes == [pl.Float64, pl.Int8]
+    assert out.dtypes == [pl.Float64, pl.Null]
     tbl = pa.Table.from_pandas(df1, preserve_index=False)
     out = cast(pl.DataFrame, pl.from_arrow(tbl))
     assert out.columns == ["b"]
@@ -567,7 +603,7 @@ def test_from_null_column() -> None:
 
     assert df.shape == (2, 1)
     assert df.columns == ["n/a"]
-    assert dtype_to_py_type(df.dtypes[0]) == int
+    assert dtype_to_py_type(df.dtypes[0]) is None
 
 
 def test_to_pandas_series() -> None:
@@ -671,3 +707,35 @@ def test_from_pyarrow_map() -> None:
             [{"key": "a", "value": "else"}, {"key": "b", "value": "another key"}],
         ],
     }
+
+
+def test_to_numpy_datelike() -> None:
+    s = pl.Series(
+        "dt",
+        [
+            datetime(2022, 7, 5, 10, 30, 45, 123456),
+            None,
+            datetime(2023, 2, 5, 15, 22, 30, 987654),
+        ],
+    )
+    assert str(s.to_numpy()) == str(
+        np.array(
+            ["2022-07-05T10:30:45.123456", "NaT", "2023-02-05T15:22:30.987654"],
+            dtype="datetime64[us]",
+        )
+    )
+    assert str(s.drop_nulls().to_numpy()) == str(
+        np.array(
+            ["2022-07-05T10:30:45.123456", "2023-02-05T15:22:30.987654"],
+            dtype="datetime64[us]",
+        )
+    )
+
+
+@typing.no_type_check
+def test_from_fixed_size_binary_list() -> None:
+    val = [[b"63A0B1C66575DD5708E1EB2B"]]
+    arrow_array = pa.array(val, type=pa.list_(pa.binary(24)))
+    s = pl.from_arrow(arrow_array)
+    assert s.dtype == pl.List(pl.Binary)
+    assert s.to_list() == val
