@@ -4,11 +4,10 @@ from datetime import date, datetime, time
 from functools import reduce
 from operator import add
 from string import ascii_letters
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any, cast
 
 import numpy as np
 import pytest
-from _pytest.capture import CaptureFixture
 
 import polars as pl
 from polars import col, lit, when
@@ -16,6 +15,9 @@ from polars.datatypes import NUMERIC_DTYPES, PolarsDataType
 from polars.testing import assert_frame_equal
 from polars.testing.asserts import assert_series_equal
 
+if TYPE_CHECKING:
+    from _pytest.capture import CaptureFixture
+
 
 def test_lazy() -> None:
     df = pl.DataFrame({"a": [1, 2, 3], "b": [1.0, 2.0, 3.0]})
@@ -194,7 +196,7 @@ def test_apply_custom_function() -> None:
                 pl.count("cars").alias("cars_count"),
             ]
         )
-        .sort("custom_1", reverse=True)
+        .sort("custom_1", descending=True)
     ).collect()
     expected = pl.DataFrame(
         {
@@ -396,7 +398,7 @@ def test_fold_filter() -> None:
     out = df.filter(
         pl.fold(
             acc=pl.lit(True),
-            f=lambda a, b: a & b,
+            function=lambda a, b: a & b,
             exprs=[pl.col(c) > 1 for c in df.columns],
         )
     )
@@ -406,7 +408,7 @@ def test_fold_filter() -> None:
     out = df.filter(
         pl.fold(
             acc=pl.lit(True),
-            f=lambda a, b: a | b,
+            function=lambda a, b: a | b,
             exprs=[pl.col(c) > 1 for c in df.columns],
         )
     )
@@ -456,7 +458,7 @@ def test_head_groupby() -> None:
     # this query flexes the wildcard exclusion quite a bit.
     keys = ["commodity", "location"]
     out = (
-        df.sort(by="price", reverse=True)
+        df.sort(by="price", descending=True)
         .groupby(keys, maintain_order=True)
         .agg([col("*").exclude(keys).head(2).keep_name()])
         .explode(col("*").exclude(keys))
@@ -973,20 +975,6 @@ def test_ufunc_expr_not_first() -> None:
     assert_frame_equal(out, expected)
 
 
-def test_ufunc_multiple_expr() -> None:
-    df = pl.DataFrame(
-        [
-            pl.Series("a", [1, 2, 3], dtype=pl.Float64),
-            pl.Series("b", [4, 5, 6], dtype=pl.Float64),
-        ]
-    )
-
-    with pytest.raises(
-        ValueError, match="Numpy ufunc can only be used with one expression, 2 given"
-    ):
-        df.select(np.arctan2(pl.col("a"), pl.col("b")))  # type: ignore[call-overload]
-
-
 def test_clip() -> None:
     df = pl.DataFrame({"a": [1, 2, 3, 4, 5]})
     assert df.select(pl.col("a").clip(2, 4))["a"].to_list() == [2, 2, 3, 4, 4]
@@ -1358,9 +1346,13 @@ def test_head_tail(fruits_cars: pl.DataFrame) -> None:
 
 def test_lower_bound_upper_bound(fruits_cars: pl.DataFrame) -> None:
     res_expr = fruits_cars.select(pl.col("A").lower_bound())
-    assert res_expr["A"][0] < -10_000_000
-    res_expr = fruits_cars.select(pl.col("A").upper_bound())
-    assert res_expr["A"][0] > 10_000_000
+    assert res_expr.item() == -9223372036854775808
+
+    res_expr = fruits_cars.select(pl.col("B").upper_bound())
+    assert res_expr.item() == 9223372036854775807
+
+    with pytest.raises(pl.ComputeError):
+        fruits_cars.select(pl.col("fruits").upper_bound())
 
 
 def test_nested_min_max() -> None:
@@ -1475,9 +1467,13 @@ def test_lazy_schema() -> None:
     ).lazy()
     assert lf.dtypes == [pl.Int64, pl.Float64, pl.Utf8]
 
-    lfe = lf.cleared()
+    lfe = lf.clear()
     assert lfe.schema == lf.schema
 
+    lfe = lf.clear(2)
+    assert lfe.schema == lf.schema
+    assert lfe.collect().rows() == [(None, None, None), (None, None, None)]
+
 
 def test_deadlocks_3409() -> None:
     assert (
@@ -1665,3 +1661,67 @@ def test_cumagg_types() -> None:
     assert cumprod_lf.schema["c"] == pl.Float64
     collected_cumprod_lf = cumprod_lf.collect()
     assert collected_cumprod_lf.schema == cumprod_lf.schema
+
+
+def test_col() -> None:
+    df = pl.DataFrame(
+        {
+            "ham": [1, 2, 3],
+            "hamburger": [11, 22, 33],
+            "foo": [3, 2, 1],
+            "bar": ["a", "b", "c"],
+        }
+    )
+
+    # Single column
+    assert df.select(pl.col("foo")).columns == ["foo"]
+    # Regex
+    assert df.select(pl.col("*")).columns == ["ham", "hamburger", "foo", "bar"]
+    assert df.select(pl.col("^ham.*$")).columns == ["ham", "hamburger"]
+    assert df.select(pl.col("*").exclude("ham")).columns == ["hamburger", "foo", "bar"]
+    # Multiple inputs
+    assert df.select(pl.col(["hamburger", "foo"])).columns == ["hamburger", "foo"]
+    assert df.select(pl.col("hamburger", "foo")).columns == ["hamburger", "foo"]
+    assert df.select(pl.col(pl.Series(["ham", "foo"]))).columns == ["ham", "foo"]
+    # Dtypes
+    assert df.select(pl.col(pl.Utf8)).columns == ["bar"]
+    assert df.select(pl.col(pl.Int64, pl.Float64)).columns == [
+        "ham",
+        "hamburger",
+        "foo",
+    ]
+
+
+def test_compare_schema_between_lazy_and_eager_6904() -> None:
+    float32_df = pl.DataFrame({"x": pl.Series(values=[], dtype=pl.Float32)})
+    eager_result = float32_df.select(pl.col("x").sqrt()).select(pl.col(pl.Float32))
+    lazy_result = (
+        float32_df.lazy()
+        .select(pl.col("x").sqrt())
+        .select(pl.col(pl.Float32))
+        .collect()
+    )
+    assert eager_result.shape == lazy_result.shape
+
+    eager_result = float32_df.select(pl.col("x").pow(2)).select(pl.col(pl.Float32))
+    lazy_result = (
+        float32_df.lazy()
+        .select(pl.col("x").pow(2))
+        .select(pl.col(pl.Float32))
+        .collect()
+    )
+    assert eager_result.shape == lazy_result.shape
+
+    int32_df = pl.DataFrame({"x": pl.Series(values=[], dtype=pl.Int32)})
+    eager_result = int32_df.select(pl.col("x").pow(2)).select(pl.col(pl.Float64))
+    lazy_result = (
+        int32_df.lazy().select(pl.col("x").pow(2)).select(pl.col(pl.Float64)).collect()
+    )
+    assert eager_result.shape == lazy_result.shape
+
+    int8_df = pl.DataFrame({"x": pl.Series(values=[], dtype=pl.Int8)})
+    eager_result = int8_df.select(pl.col("x").diff()).select(pl.col(pl.Int16))
+    lazy_result = (
+        int8_df.lazy().select(pl.col("x").diff()).select(pl.col(pl.Int16)).collect()
+    )
+    assert eager_result.shape == lazy_result.shape
