@@ -24,11 +24,10 @@ from polars.datatypes import (
 )
 from polars.exceptions import ShapeError
 from polars.internals.construction import iterable_to_pyseries
-from polars.internals.type_aliases import EpochTimeUnit
 from polars.testing import assert_frame_equal, assert_series_equal
 
 if TYPE_CHECKING:
-    from polars.internals.type_aliases import TimeUnit
+    from polars.internals.type_aliases import EpochTimeUnit, TimeUnit
 
 
 def test_cum_agg() -> None:
@@ -505,7 +504,7 @@ def test_to_python() -> None:
 def test_sort() -> None:
     a = pl.Series("a", [2, 1, 3])
     assert_series_equal(a.sort(), pl.Series("a", [1, 2, 3]))
-    assert_series_equal(a.sort(reverse=True), pl.Series("a", [3, 2, 1]))
+    assert_series_equal(a.sort(descending=True), pl.Series("a", [3, 2, 1]))
 
 
 def test_rechunk() -> None:
@@ -1012,9 +1011,11 @@ def test_empty() -> None:
     )
 
     a = pl.Series(name="a", values=[1, 2, 3], dtype=pl.Int16)
-    empty_a = a.cleared()
-    assert a.dtype == empty_a.dtype
-    assert len(empty_a) == 0
+    for n in (0, 2, 5):
+        empty_a = a.clear(n)
+        assert a.dtype == empty_a.dtype
+        assert a.name == empty_a.name
+        assert len(empty_a) == n
 
     with pytest.raises(ValueError, match="ambiguous"):
         not empty_a
@@ -1188,7 +1189,7 @@ def test_rank() -> None:
     assert df.select(pl.col("a").rank("dense"))["a"].to_list() == [2, 3, 4, 3, 3, 4, 1]
 
     assert_series_equal(
-        s.rank("dense", reverse=True),
+        s.rank("dense", descending=True),
         pl.Series("a", [3, 2, 1, 2, 2, 1, 4], dtype=UInt32),
     )
 
@@ -1628,8 +1629,8 @@ def test_arg_sort() -> None:
 
     assert_series_equal(s.arg_sort(), expected)
 
-    expected_reverse = pl.Series("a", [0, 2, 1, 4, 3], dtype=UInt32)
-    assert_series_equal(s.arg_sort(reverse=True), expected_reverse)
+    expected_descending = pl.Series("a", [0, 2, 1, 4, 3], dtype=UInt32)
+    assert_series_equal(s.arg_sort(descending=True), expected_descending)
 
 
 def test_arg_min_and_arg_max() -> None:
@@ -1660,7 +1661,7 @@ def test_arg_min_and_arg_max() -> None:
     assert s.arg_min() == 0
     assert s.arg_max() == 4
     s = pl.Series("a", [5, 4, 3, 2, 1])
-    s.sort(reverse=True, in_place=True)  # set descing sorted flag
+    s.sort(descending=True, in_place=True)  # set descing sorted flag
     assert s.flags == {"SORTED_ASC": False, "SORTED_DESC": True}
     assert s.arg_min() == 4
     assert s.arg_max() == 0
@@ -1688,6 +1689,20 @@ def test_is_unique() -> None:
     s = pl.Series("a", [1, 2, 2, 3])
     assert_series_equal(s.is_unique(), pl.Series("a", [True, False, False, True]))
 
+    # utf8
+    assert pl.Series(["a", "b", "c", "a"]).is_duplicated().to_list() == [
+        True,
+        False,
+        False,
+        True,
+    ]
+    assert pl.Series(["a", "b", "c", "a"]).is_unique().to_list() == [
+        False,
+        True,
+        True,
+        False,
+    ]
+
 
 def test_is_duplicated() -> None:
     s = pl.Series("a", [1, 2, 2, 3])
@@ -2392,3 +2407,78 @@ def test_is_between() -> None:
         True,
         False,
     ]
+
+
+def test_map_dict() -> None:
+    s = pl.Series("s", [-1, 2, None, 4, -5])
+    remap = {1: "one", 2: "two", 3: "three", 4: "four", 5: "five"}
+
+    assert_series_equal(
+        s.abs().map_dict(remap, default="?"),
+        pl.Series("s", ["one", "two", "?", "four", "five"]),
+    )
+    assert_series_equal(
+        s.map_dict(remap, default=s.cast(pl.Utf8)),
+        pl.Series("s", ["-1", "two", None, "four", "-5"]),
+    )
+
+
+@pytest.mark.parametrize(
+    ("dtype", "lower", "upper"),
+    [
+        (pl.Int8, -128, 127),
+        (pl.UInt8, 0, 255),
+        (pl.Int16, -32768, 32767),
+        (pl.UInt16, 0, 65535),
+        (pl.Int32, -2147483648, 2147483647),
+        (pl.UInt32, 0, 4294967295),
+        (pl.Int64, -9223372036854775808, 9223372036854775807),
+        (pl.UInt64, 0, 18446744073709551615),
+        (pl.Float32, float("-inf"), float("inf")),
+        (pl.Float64, float("-inf"), float("inf")),
+    ],
+)
+def test_upper_lower_bounds(
+    dtype: PolarsDataType, upper: int | float, lower: int | float
+) -> None:
+    s = pl.Series("s", dtype=dtype)
+    assert s.lower_bound().item() == lower
+    assert s.upper_bound().item() == upper
+
+
+def test_numpy_series_arithmetic() -> None:
+    sx = pl.Series(values=[1, 2])
+    y = np.array([3.0, 4.0])
+
+    result_add1 = y + sx
+    result_add2 = sx + y
+    expected_add = pl.Series([4.0, 6.0], dtype=pl.Float64)
+    assert_series_equal(result_add1, expected_add)  # type: ignore[arg-type]
+    assert_series_equal(result_add2, expected_add)
+
+    result_sub1 = cast(pl.Series, y - sx)  # py37 is different vs py311 on this one
+    expected = pl.Series([2.0, 2.0], dtype=pl.Float64)
+    assert_series_equal(result_sub1, expected)
+    result_sub2 = sx - y
+    expected = pl.Series([-2.0, -2.0], dtype=pl.Float64)
+    assert_series_equal(result_sub2, expected)
+
+    result_mul1 = y * sx
+    result_mul2 = sx * y
+    expected = pl.Series([3.0, 8.0], dtype=pl.Float64)
+    assert_series_equal(result_mul1, expected)  # type: ignore[arg-type]
+    assert_series_equal(result_mul2, expected)
+
+    result_div1 = y / sx
+    expected = pl.Series([3.0, 2.0], dtype=pl.Float64)
+    assert_series_equal(result_div1, expected)  # type: ignore[arg-type]
+    result_div2 = sx / y
+    expected = pl.Series([1 / 3, 0.5], dtype=pl.Float64)
+    assert_series_equal(result_div2, expected)
+
+    result_pow1 = y**sx
+    expected = pl.Series([3.0, 16.0], dtype=pl.Float64)
+    assert_series_equal(result_pow1, expected)  # type: ignore[arg-type]
+    result_pow2 = sx**y
+    expected = pl.Series([1.0, 16.0], dtype=pl.Float64)
+    assert_series_equal(result_pow2, expected)  # type: ignore[arg-type]
